@@ -1,9 +1,9 @@
 /* Compatibility routines.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -22,11 +22,11 @@
 const char *hstrerror(int h_errnum)
 {
     switch (h_errnum) {
-	case HOST_NOT_FOUND: return "Host not found";
-	case TRY_AGAIN:      return "Host not found, try again";
-	case NO_RECOVERY:    return "Nameserver error";
-	case NO_DATA:        return "No data of requested type";
-	default:             return "Unknown error";
+        case HOST_NOT_FOUND: return "Host not found";
+        case TRY_AGAIN:      return "Host not found, try again";
+        case NO_RECOVERY:    return "Nameserver error";
+        case NO_DATA:        return "No data of requested type";
+        default:             return "Unknown error";
     }
 }
 
@@ -45,7 +45,7 @@ const char *hstrerror(int h_errnum)
 int vsnprintf(char *buf, size_t len, const char *fmt, va_list args)
 {
     if (len <= 0)
-	return 0;
+        return 0;
     *buf = 0;
 #undef vsnprintf
     vsnprintf(buf, len, fmt, args);
@@ -53,7 +53,7 @@ int vsnprintf(char *buf, size_t len, const char *fmt, va_list args)
     buf[len-1] = 0;
     return strlen(buf);
 }
-#endif	/* BAD_SNPRINTF */
+#endif  /* BAD_SNPRINTF */
 
 int snprintf(char *buf, size_t len, const char *fmt, ...)
 {
@@ -84,16 +84,16 @@ char *strtok(char *str, const char *delim)
     char *ret;
 
     if (str)
-	current = str;
+        current = str;
     if (!current)
-	return NULL;
+        return NULL;
     current += strspn(current, delim);
     ret = *current ? current : NULL;
     current += strcspn(current, delim);
     if (!*current)
-	current = NULL;
+        current = NULL;
     else
-	*current++ = 0;
+        *current++ = 0;
     return ret;
 }
 
@@ -112,13 +112,13 @@ int stricmp(const char *s1, const char *s2)
     register int c;
 
     while ((c = tolower(*s1)) == tolower(*s2)) {
-	if (c == 0)
-	    return 0;
-	s1++;
-	s2++;
+        if (c == 0)
+            return 0;
+        s1++;
+        s2++;
     }
     if (c < tolower(*s2))
-	return -1;
+        return -1;
     return 1;
 }
 
@@ -127,27 +127,27 @@ int strnicmp(const char *s1, const char *s2, size_t len)
     register int c;
 
     if (!len)
-	return 0;
+        return 0;
     while ((c = tolower(*s1)) == tolower(*s2) && len > 0) {
-	if (c == 0 || --len == 0)
-	    return 0;
-	s1++;
-	s2++;
+        if (c == 0 || --len == 0)
+            return 0;
+        s1++;
+        s2++;
     }
     if (c < tolower(*s2))
-	return -1;
+        return -1;
     return 1;
 }
 #endif
 
 /*************************************************************************/
 
-#if !HAVE_STRDUP
+#if !HAVE_STRDUP && !MEMCHECKS
 char *strdup(const char *s)
 {
     char *new = malloc(strlen(s)+1);
     if (new)
-	strcpy(new, s);
+        strcpy(new, s);
     return new;
 }
 #endif
@@ -161,7 +161,7 @@ size_t strspn(const char *s, const char *accept)
     size_t i = 0;
 
     while (*s && strchr(accept, *s))
-	++i, ++s;
+        ++i, ++s;
     return i;
 }
 
@@ -170,7 +170,7 @@ size_t strcspn(const char *s, const char *reject)
     size_t i = 0;
 
     while (*s && !strchr(reject, *s))
-	++i, ++s;
+        ++i, ++s;
     return i;
 }
 
@@ -202,39 +202,47 @@ char *strsignal(int signum)
 {
     static char buf[32];
     switch (signum) {
-	case SIGHUP:	strscpy(buf, "Hangup", sizeof(buf));		break;
-	case SIGINT:	strscpy(buf, "Interrupt", sizeof(buf));		break;
-	case SIGQUIT:	strscpy(buf, "Quit", sizeof(buf));		break;
+        case SIGHUP:    strbcpy(buf, "Hangup");                         break;
+        case SIGINT:    strbcpy(buf, "Interrupt");                      break;
+        case SIGQUIT:   strbcpy(buf, "Quit");                           break;
 #ifdef SIGILL
-	case SIGILL:	strscpy(buf, "Illegal instruction", sizeof(buf));
-			break;
+        case SIGILL:    strbcpy(buf, "Illegal instruction");            break;
 #endif
 #ifdef SIGABRT
-	case SIGABRT:	strscpy(buf, "Abort", sizeof(buf));		break;
+        case SIGABRT:   strbcpy(buf, "Abort");                          break;
 #endif
 #if defined(SIGIOT) && (!defined(SIGABRT) || SIGIOT != SIGABRT)
-	case SIGIOT:	strscpy(buf, "IOT trap", sizeof(buf));		break;
+        case SIGIOT:    strbcpy(buf, "IOT trap");                       break;
 #endif
 #ifdef SIGBUS
-	case SIGBUS:	strscpy(buf, "Bus error", sizeof(buf));		break;
+        case SIGBUS:    strbcpy(buf, "Bus error");                      break;
 #endif
-	case SIGFPE:	strscpy(buf, "Floating point exception", sizeof(buf));
-			break;
-	case SIGKILL:	strscpy(buf, "Killed", sizeof(buf));		break;
-	case SIGUSR1:	strscpy(buf, "User signal 1", sizeof(buf));	break;
-	case SIGSEGV:	strscpy(buf, "Segmentation fault", sizeof(buf));break;
-	case SIGUSR2:	strscpy(buf, "User signal 2", sizeof(buf));	break;
-	case SIGPIPE:	strscpy(buf, "Broken pipe", sizeof(buf));	break;
-	case SIGALRM:	strscpy(buf, "Alarm clock", sizeof(buf));	break;
-	case SIGTERM:	strscpy(buf, "Terminated", sizeof(buf));	break;
-	case SIGSTOP:	strscpy(buf, "Suspended (signal)", sizeof(buf));break;
-	case SIGTSTP:	strscpy(buf, "Suspended", sizeof(buf));		break;
-	case SIGIO:	strscpy(buf, "I/O error", sizeof(buf));		break;
-	default:	snprintf(buf, sizeof(buf), "Signal %d\n", signum);
-			break;
+        case SIGFPE:    strbcpy(buf, "Floating point exception");       break;
+        case SIGKILL:   strbcpy(buf, "Killed");                         break;
+        case SIGUSR1:   strbcpy(buf, "User signal 1");                  break;
+        case SIGSEGV:   strbcpy(buf, "Segmentation fault");             break;
+        case SIGUSR2:   strbcpy(buf, "User signal 2");                  break;
+        case SIGPIPE:   strbcpy(buf, "Broken pipe");                    break;
+        case SIGALRM:   strbcpy(buf, "Alarm clock");                    break;
+        case SIGTERM:   strbcpy(buf, "Terminated");                     break;
+        case SIGSTOP:   strbcpy(buf, "Stopped (signal)");               break;
+        case SIGTSTP:   strbcpy(buf, "Stopped");                        break;
+        case SIGIO:     strbcpy(buf, "I/O error");                      break;
+        default:        snprintf(buf, sizeof(buf), "Signal %d\n", signum);
+                        break;
     }
     return buf;
 }
 #endif
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
