@@ -1,9 +1,9 @@
 /* Basic constants, macros and prototypes.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -17,16 +17,16 @@
 /******* General configuration *******/
 
 /* Name of configuration file (in Services directory) */
-#define IRCSERVICES_CONF	"ircservices.conf"
+#define IRCSERVICES_CONF        PROGRAM ".conf"
 
 /* Name of module configuration file (in Services directory) */
-#define MODULES_CONF		"modules.conf"
+#define MODULES_CONF            "modules.conf"
 
 /* Maximum number of parameters for a configuration directive */
-#define CONFIG_MAXPARAMS	8
+#define CONFIG_MAXPARAMS        8
 
 /* Maximum number of channels to buffer modes for (for MergeChannelModes) */
-#define MERGE_CHANMODES_MAX	3
+#define MERGE_CHANMODES_MAX     3
 
 
 /******* NickServ configuration *******/
@@ -34,7 +34,7 @@
 /* Default language for newly registered nicks; see language.h for
  * available languages (LANG_* constants).  Unless you're running a
  * regional network, you should probably leave this at LANG_EN_US. */
-#define DEF_LANGUAGE	LANG_EN_US
+#define DEF_LANGUAGE    LANG_EN_US
 
 
 /******* OperServ configuration *******/
@@ -54,35 +54,44 @@
 /* Size of input buffer (note: this is different from BUFSIZ)
  * This MUST be big enough to hold at least one full IRC message, or Bad
  * Things will happen. */
-#define BUFSIZE		1024
-
-/* Minimum (also initial) buffer size for network connections; also serves
- * as increment for buffer expansion */
-#define NET_MIN_BUFSIZE	4096
+#define BUFSIZE         1024
 
 /* Maximum length of a configuration file line */
-#define CONFIG_LINEMAX	4096
+#define CONFIG_LINEMAX  4096
 
 /* Size of memory-based log buffer (only used with SHOWALLOCS) */
-#define LOGMEMSIZE	65536
+#define LOGMEMSIZE      65536
 
 /*************************************************************************/
 
-/* WARNING:  If you change these, your data files will be unusable! */
+/*
+ * The following constants define the sizes of channel name, nickname, and
+ * password buffers used in Services.  These should only be adjusted if
+ * your IRC network allows longer nicknames or channel names _and_ you wish
+ * to allow such names to be used with Services.  If your IRC network has
+ * smaller limits, you do not need to change these values; Services will
+ * still work fine, albeit with a tiny amount of wasted memory for each
+ * nickname and channel.
+ *
+ * WARNING:  If you change these, you MUST back up your data to an XML file
+ * before making the change, and re-import the data afterwards.  Database
+ * files created with different calues of CHANMAX/NICKMAX/PASSMAX are not
+ * compatible!
+ */
 
 /* Maximum length of a channel name, including the trailing null.  Any
  * channels with a length longer than CHANMAX-1 (including the leading #)
  * will not be usable with ChanServ. */
-#define CHANMAX		64
+#define CHANMAX         64
 
 /* Maximum length of a nickname, including the trailing null.  This MUST be
  * at least one greater than the maximum allowable nickname length on your
  * network, or people will run into problems using Services!  The default
- * (32) works with all servers I know of. */
-#define NICKMAX		32
+ * (32) should work for all current servers. */
+#define NICKMAX         32
 
-/* Maximum length of a password */
-#define PASSMAX		32
+/* Maximum length of an unencrypted password, including the trailing null. */
+#define PASSMAX         32
 
 /*************************************************************************/
 
@@ -110,8 +119,7 @@
 /* Common includes/prototypes. */
 
 
-/* Some Linux boxes (or maybe glibc includes) require this for the
- * prototype of strsignal(). */
+/* glibc seems to require this for the prototype of strsignal(). */
 #define _GNU_SOURCE
 
 /* Some AIX boxes define int16 and int32 on their own.  Blarph. */
@@ -121,24 +129,33 @@
 #endif
 
 
+/* We have our own encrypt(). */
+#define encrypt encrypt_
+
 #include <stdarg.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
-#define __GNU_SOURCE  /* for strsignal() with glibc */
 #undef DEFS_H  /* kludge to work around Cygwin string.h kludge to work
                 * around problem compiling in gdb... this is stupid */
 #include <string.h>
 #define DEFS_H
-#undef __GNU_SOURCE
 #include <unistd.h>
 #include <signal.h>
 #include <time.h>
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
+#include <math.h>
 #include <sys/types.h>
 #include <sys/time.h>
 
+#undef encrypt
+
+#if HAVE_STDINT_H
+# include <stdint.h>
+#endif
+
 #if HAVE_STRINGS_H
 # include <strings.h>
 #endif
@@ -155,7 +172,7 @@
  * prototypes. */
 extern int strcasecmp(const char *, const char *);
 extern int strncasecmp(const char *, const char *, size_t);
-# if 0	/* These break on some AIX boxes (4.3.1 reported). */
+# if 0  /* These break on some AIX boxes (4.3.1 reported). */
 extern int gettimeofday(struct timeval *, struct timezone *);
 extern int socket(int, int, int);
 extern int bind(int, struct sockaddr *, int);
@@ -173,9 +190,6 @@ extern int shutdown(int, int);
 # define strnicmp strncasecmp
 #endif
 
-/* We have our own encrypt(). */
-#define encrypt encrypt_
-
 /* socklen_t for systems without it. */
 #if !HAVE_SOCKLEN_T
 typedef int socklen_t;
@@ -213,13 +227,13 @@ typedef int socklen_t;
 
 /* Make sizeof() return an int regardless of compiler (avoids printf
  * argument type warnings). */
-#define sizeof(v)	((int)sizeof(v))
+#define sizeof(v)       ((int)sizeof(v))
 
 /* Length of an array: */
-#define lenof(a)	(sizeof(a) / sizeof(*(a)))
+#define lenof(a)        (sizeof(a) / sizeof(*(a)))
 
 /* Sign of a number: (-1, 0, or 1) */
-#define sgn(a)		((a)<0 ? -1 : ((a)>0))
+#define sgn(n)          ((n)<0 ? -1 : ((n)>0))
 
 /* Telling compilers about printf()-like functions: */
 #ifdef __GNUC__
@@ -248,22 +262,18 @@ typedef int socklen_t;
 /* Generic "invalid" pointer value.  For use when an "invalid" value is
  * needed and NULL cannot be used. */
 
-#define PTR_INVALID	((const char *)-1)
+#define PTR_INVALID     ((const char *)-1)
 
 /*************************************************************************/
 
-/* Hack for sigsetjmp(); since (at least with glibc, and it shouldn't hurt
- * anywhere else) sigsetjmp() only works if you don't leave the stack frame
- * it was called from, we have to call it before calling the signals.c
- * wrapper. */
+#endif  /* DEFS_H */
 
-#include <setjmp.h>
-#define DO_SIGSETJMP() {	\
-    static sigjmp_buf buf;	\
-    if (!sigsetjmp(buf, 1))	\
-	do_sigsetjmp(&buf);	\
-}
-
-/*************************************************************************/
-
-#endif	/* DEFS_H */
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
