@@ -1,14 +1,18 @@
 /* Miscellaneous routines.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
 #include "services.h"
-#include <fcntl.h>
+
+#ifdef CONVERT_DB
+# undef log
+# define log(...) fprintf(stderr, __VA_ARGS__)
+#endif
 
 /*************************************************************************/
 
@@ -65,6 +69,7 @@ unsigned char irc_lowertable[256] = {
  *               irc_str[n]icmp()'s benefit.
  */
 
+#undef irc_tolower
 inline unsigned char irc_tolower(char c)
 {
     return irc_lowertable[(uint8)c];
@@ -79,10 +84,10 @@ int irc_stricmp(const char *s1, const char *s2)
     register char c1, c2;
 
     while ((c1 = (char)irc_tolower(*s1)) == (c2 = (char)irc_tolower(*s2))) {
-	if (c1 == 0)
-	    return 0;
-	s1++;
-	s2++;
+        if (c1 == 0)
+            return 0;
+        s1++;
+        s2++;
     }
     return c1<c2 ? -1 : 1;
 }
@@ -92,12 +97,12 @@ int irc_strnicmp(const char *s1, const char *s2, int max)
     register char c1, c2;
 
     if (max <= 0)
-	return 0;
+        return 0;
     while ((c1 = (char)irc_tolower(*s1)) == (c2 = (char)irc_tolower(*s2))) {
-	if (c1 == 0 || --max <= 0)
-	    return 0;
-	s1++;
-	s2++;
+        if (c1 == 0 || --max <= 0)
+            return 0;
+        s1++;
+        s2++;
     }
     return c1<c2 ? -1 : 1;
 }
@@ -106,6 +111,9 @@ int irc_strnicmp(const char *s1, const char *s2, int max)
 
 /* strscpy:  Copy at most len-1 characters from a string to a buffer, and
  *           add a null terminator after the last character copied.
+ *           The `strbcpy(d,s)' variant (defined as a macro in extern.h)
+ *           assumes `d' is a character array and uses sizeof(d) as the
+ *           `len' parameter.
  */
 
 char *strscpy(char *d, const char *s, size_t len)
@@ -113,9 +121,9 @@ char *strscpy(char *d, const char *s, size_t len)
     char *d_orig = d;
 
     if (!len)
-	return d;
+        return d;
     while (--len && (*d++ = *s++))
-	;
+        ;
     *d = 0;
     return d_orig;
 }
@@ -126,7 +134,7 @@ char *strscpy(char *d, const char *s, size_t len)
  *           properly.  The str*() analog of memmove().
  */
 
-char *strmove(char *d, char *s)
+char *strmove(char *d, const char *s)
 {
     memmove(d, s, strlen(s)+1);
     return d;
@@ -144,15 +152,15 @@ char *stristr(const char *s1, const char *s2)
     register const char *s = s1, *d = s2;
 
     while (*s1) {
-	if (tolower(*s1) == tolower(*d)) {
-	    s1++;
-	    d++;
-	    if (*d == 0)
-		return (char *)s;
-	} else {
-	    s = ++s1;
-	    d = s2;
-	}
+        if (tolower(*s1) == tolower(*d)) {
+            s1++;
+            d++;
+            if (*d == 0)
+                return (char *)s;
+        } else {
+            s = ++s1;
+            d = s2;
+        }
     }
     return NULL;
 }
@@ -166,8 +174,8 @@ char *strupper(char *s)
 {
     char *t = s;
     while (*t) {
-	*t = toupper(*t);
-	t++;
+        *t = toupper(*t);
+        t++;
     }
     return s;
 }
@@ -176,8 +184,8 @@ char *strlower(char *s)
 {
     char *t = s;
     while (*t) {
-	*t = tolower(*t);
-	t++;
+        *t = tolower(*t);
+        t++;
     }
     return s;
 }
@@ -199,19 +207,21 @@ char *strnrepl(char *s, int32 size, const char *old, const char *new)
     int32 newlen = strlen(new);
     int32 diff = newlen - oldlen;
 
+    if (avail < 0)  /* silly parameter */
+        avail = 0;
     while (left >= oldlen) {
-	if (strncmp(ptr, old, oldlen) != 0) {
-	    left--;
-	    ptr++;
-	    continue;
-	}
-	if (diff > avail)
-	    break;
-	if (diff != 0)
-	    memmove(ptr+oldlen+diff, ptr+oldlen, left+1);
-	strncpy(ptr, new, newlen);
-	ptr += newlen;
-	left -= oldlen;
+        if (strncmp(ptr, old, oldlen) != 0) {
+            left--;
+            ptr++;
+            continue;
+        }
+        if (diff > avail)
+            break;
+        if (diff != 0)
+            memmove(ptr+oldlen+diff, ptr+oldlen, left+1);
+        strncpy(ptr, new, newlen);
+        ptr += newlen;
+        left -= oldlen;
     }
     return s;
 }
@@ -227,13 +237,13 @@ char *strtok_remaining(void)
 {
     char *s = strtok(NULL, ""), *t;
     if (s) {
-	while (isspace(*s))
-	    s++;
-	t = s + strlen(s)-1;
-	while (t >= s && isspace(*t))
-	    *t-- = 0;
-	if (!*s)
-	    return NULL;
+        while (isspace(*s))
+            s++;
+        t = s + strlen(s)-1;
+        while (t >= s && isspace(*t))
+            *t-- = 0;
+        if (!*s)
+            return NULL;
     }
     return s;
 }
@@ -243,7 +253,8 @@ char *strtok_remaining(void)
 
 /* merge_args:  Take an argument count and argument vector and merge them
  *              into a single string in which each argument is separated by
- *              a space.
+ *              a space.  The returned string is stored in a static buffer
+ *              which will be overwritten on the next call.
  */
 
 char *merge_args(int argc, char **argv)
@@ -253,8 +264,10 @@ char *merge_args(int argc, char **argv)
     char *t;
 
     t = s;
-    for (i = 0; i < argc; i++)
-	t += snprintf(t, sizeof(s)-(t-s), "%s%s", *argv++, (i<argc-1) ? " " : "");
+    for (i = 0; i < argc; i++) {
+        t += snprintf(t, sizeof(s)-(t-s), "%s%s", *argv++,
+                      (i<argc-1) ? " " : "");
+    }
     return s;
 }
 
@@ -271,43 +284,54 @@ static int do_match_wild(const char *pattern, const char *str, int docase)
     char c;
     const char *s;
 
-    /* This WILL eventually terminate: either by *pattern == 0, or by a
-     * trailing '*' (or "*???..."). */
+    /* Sanity-check pointer parameters */
+
+    if (pattern == NULL) {
+        log("BUG or corrupted database: pattern == NULL in do_match_wild())");
+        return 0;
+    }
+    if (str == NULL) {
+        log("BUG or corrupted database: str == NULL in do_match_wild())");
+        return 0;
+    }
+
+    /* This loop is guaranteed to terminate, either by *pattern == 0 (the
+     * end of the pattern string) or a trailing '*' (or "*???..."). */
 
     for (;;) {
-	switch (c = *pattern++) {
-	  case 0:
-	    if (!*str)
-		return 1;
-	    return 0;
-	  case '?':
-	    if (!*str)
-		return 0;
-	    str++;
-	    break;
-	  case '*':
-	    while (*pattern == '?') {
-		if (!*str)
-		    return 0;
-		str++;		/* skip a character for each '?' */
-		pattern++;
-	    }
-	    if (!*pattern)
-		return 1;	/* trailing '*' matches everything else */
-	    s = str;
-	    while (*s) {
-		if ((docase ? (*s==*pattern) : (tolower(*s)==tolower(*pattern)))
-					&& do_match_wild(pattern+1, s+1, docase))
-		    return 1;
-		s++;
-	    }
-	    break;
-	  default:
-	    if (docase ? (*str != c) : (tolower(*str) != tolower(c)))
-		return 0;
-	    str++;
-	    break;
-	} /* switch */
+        switch (c = *pattern++) {
+          case 0:
+            if (!*str)
+                return 1;
+            return 0;
+          case '?':
+            if (!*str)
+                return 0;
+            str++;
+            break;
+          case '*':
+            while (*pattern == '?') {
+                if (!*str)
+                    return 0;
+                str++;          /* skip a character for each '?' */
+                pattern++;
+            }
+            if (!*pattern)
+                return 1;       /* trailing '*' matches everything else */
+            s = str;
+            while (*s) {
+                if ((docase ? (*s==*pattern) : (tolower(*s)==tolower(*pattern)))
+                                        && do_match_wild(pattern+1, s+1, docase))
+                    return 1;
+                s++;
+            }
+            break;
+          default:
+            if (docase ? (*str != c) : (tolower(*str) != tolower(c)))
+                return 0;
+            str++;
+            break;
+        } /* switch */
     }
     /* not reached */
 }
@@ -328,23 +352,40 @@ int match_wild_nocase(const char *pattern, const char *str)
 
 /* Tables used by valid_nick() and valid_chan().  These tables follow the
  * RFC 1459 definitions; protocols with different definitions should modify
- * the table accordingly (bit 0 = valid as a first character, bit 1 = valid
- * as a subsequent character).  valid_{nick,chan}_table[0] should never be
- * modified.
+ * the table accordingly:
+ *    Bit 0 (0x01) = valid as a first character
+ *    Bit 1 (0x02) = valid as a subsequent character
+ *    Bit 2 (0x04) = valid as byte 1 of a 2-byte character
+ *    Bit 3 (0x08) = valid as byte 2 of a 2-byte character
+ * valid_{nick,chan}_table[0] should never be modified.
+ *
+ * 2-byte characters are handled by setting bits 2 and 3 on the appropriate
+ * single-byte entries (0x80-0xFF), then setting bits 0 and/or 1 on 2-byte
+ * entries (0x0100-0xFFFF) as needed, where the first byte of the character
+ * is the upper 8 bits of the array index and the second byte is the lower
+ * 8 bits.
+ *
+ * Note:  The grammar for nicknames in RFC 1459 excludes '|', but this
+ * contradicts an earlier statement that '|' and '\' are to be considered
+ * equivalent when comparing nicknames.  On the other hand, the reference
+ * server code (at least as far back as version 2.6.2, September 1991)
+ * allows anything from 'A' to '}', and allows all specials other than '-'
+ * at the beginning of a nick as well.  We consider the RFC to be in error
+ * and go by the reference implementation.
  */
 
-unsigned char valid_nick_table[256] = {
+unsigned char valid_nick_table[0x10000] = {
     0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,
     0,0,0,0,0,0,0,0, 0,0,0,0,0,2,0,0,  2,2,2,2,2,2,2,2, 2,2,0,0,0,0,0,0,
-    0,3,3,3,3,3,3,3, 3,3,3,3,3,3,3,3,  3,3,3,3,3,3,3,3, 3,3,3,2,0,2,2,0,
-    2,3,3,3,3,3,3,3, 3,3,3,3,3,3,3,3,  3,3,3,3,3,3,3,3, 3,3,3,2,0,2,2,0,
+    0,3,3,3,3,3,3,3, 3,3,3,3,3,3,3,3,  3,3,3,3,3,3,3,3, 3,3,3,3,3,3,3,3,
+    3,3,3,3,3,3,3,3, 3,3,3,3,3,3,3,3,  3,3,3,3,3,3,3,3, 3,3,3,3,3,3,3,0,
     0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,
     0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,
     0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,
     0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,
 };
 
-unsigned char valid_chan_table[256] = {
+unsigned char valid_chan_table[0x10000] = {
     0,2,2,2,2,2,2,0, 2,2,2,2,2,2,2,2,  2,2,2,2,2,2,2,2, 2,2,2,2,2,2,2,2,
     0,2,2,3,2,2,3,2, 2,2,2,2,0,2,2,2,  2,2,2,2,2,2,2,2, 2,2,2,2,2,2,2,2,
     2,2,2,2,2,2,2,2, 2,2,2,2,2,2,2,2,  2,2,2,2,2,2,2,2, 2,2,2,2,2,2,2,2,
@@ -362,27 +403,31 @@ unsigned char valid_chan_table[256] = {
  *                         Returns nonzero if valid, zero if not.
  */
 
-int valid_nick(const char *str)
+static int valid_nickchan(const char *str, const unsigned char *table)
 {
-    if (!(valid_nick_table[*(const unsigned char *)str] & 1))
-	return 0;
-    while (*++str) {
-	if (!(valid_nick_table[*(const unsigned char *)str] & 2))
-	    return 0;
+    int first = 1;   /* First character? */
+    int mbsave = 0;  /* First byte of a 2-byte character */
+
+    while (*str) {
+        int ch = *(const unsigned char *)str++;
+        if (mbsave) {
+            if (!(table[ch] & 8))
+                return 0;
+            ch |= mbsave<<8;
+            mbsave = 0;
+        } else if (table[ch] & 4) {
+            mbsave = ch;
+            continue;
+        }
+        if (!(table[ch] & (first ? 1 : 2)))
+            return 0;
+        first = 0;
     }
     return 1;
 }
 
-int valid_chan(const char *str)
-{
-    if (!(valid_chan_table[*(const unsigned char *)str] & 1))
-	return 0;
-    while (*++str) {
-	if (!(valid_chan_table[*(const unsigned char *)str] & 2))
-	    return 0;
-    }
-    return 1;
-}
+int valid_nick(const char *str) {return valid_nickchan(str, valid_nick_table);}
+int valid_chan(const char *str) {return valid_nickchan(str, valid_chan_table);}
 
 /*************************************************************************/
 
@@ -396,35 +441,35 @@ int valid_chan(const char *str)
  *   - Has at least one character and does not end with a dot. (not RFC)
  */
 
-#define DOMAIN_MAXLEN	255
-#define DOMPART_MAXLEN	63
+#define DOMAIN_MAXLEN   255
+#define DOMPART_MAXLEN  63
 
 int valid_domain(const char *str)
 {
     const char *s;
     int i;
     static const char valid_domain_chars[] =
-	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-.";
+        "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-.";
 
     if (!*str)
-	return 0;
+        return 0;
     if (str[strspn(str,valid_domain_chars)] != 0)
-	return 0;
+        return 0;
     s = str;
     while (s-str < DOMAIN_MAXLEN && *s) {
-	if (*s == '-' || *s == '.')
-	    return 0;
-	i = strcspn(s, ".");
-	if (i > DOMPART_MAXLEN)
-	    return 0;
-	s += i;
-	if (*s)
-	    s++;
+        if (*s == '-' || *s == '.')
+            return 0;
+        i = strcspn(s, ".");
+        if (i > DOMPART_MAXLEN)
+            return 0;
+        s += i;
+        if (*s)
+            s++;
     }
     if (s-str > DOMAIN_MAXLEN || *s)
-	return 0;
+        return 0;
     if (s[-1] == '.')
-	return 0;
+        return 0;
     return 1;
 }
 
@@ -449,41 +494,41 @@ int valid_email(const char *str)
     const char *atmark;
 
     for (s = (const unsigned char *)str; *s; s++) {
-	if (*s <= '\040')  // 040 == 0x20 == ' '
-	    return 0;
-	if (strchr("|,:;\\\"()<>", *s))
-	    return 0;
+        if (*s <= '\040')  // 040 == 0x20 == ' '
+            return 0;
+        if (strchr("|,:;\\\"()<>", *s))
+            return 0;
     }
 
     /* Find the @, and abort if there isn't one */
     atmark = strchr(str, '@');
     if (!atmark || atmark == str)
-	return 0;
+        return 0;
     atmark++;
 
     /* Don't allow [] in username */
     s = (const unsigned char *)strpbrk(str, "[]");
     if (s && (const char *)s < atmark)
-	return 0;
+        return 0;
 
     /* Check for a [1.2.3.4] type of domain */
     if (*atmark == '[') {
-	unsigned char ipstr[16];
-	const char *bracket = strchr(atmark+1, ']');
-	int len = bracket - (atmark+1);
-	/* Valid IP addresses have no more than 15 characters */
-	if (len <= 15 && !bracket[1]) {
-	    strncpy((char *)ipstr, atmark+1, len);
-	    ipstr[len] = 0;
-	    /* Use pack_ip() to see if it's a valid address */
-	    if (pack_ip((const char *)ipstr))
-		return 1;
-	}
+        unsigned char ipstr[16];
+        const char *bracket = strchr(atmark+1, ']');
+        int len = bracket - (atmark+1);
+        /* Valid IP addresses have no more than 15 characters */
+        if (len <= 15 && !bracket[1]) {
+            strncpy((char *)ipstr, atmark+1, len);
+            ipstr[len] = 0;
+            /* Use pack_ip() to see if it's a valid address */
+            if (pack_ip((const char *)ipstr))
+                return 1;
+        }
     }
 
     /* Don't allow [] in domains except for the above case */
     if (strpbrk(atmark, "[]"))
-	return 0;
+        return 0;
 
     /* Valid domain names cannot contain '@' so we just check valid_domain().
      * Also prohibit domains without dots. */
@@ -497,145 +542,66 @@ int valid_email(const char *str)
  *   - Contains a series of letters followed by "://" followed by a valid
  *     domain name, possibly followed by a : and a numeric port number in
  *     the range 1-65535, followed either by a slash and possibly more text
- *     by nothing.
+ *     or by nothing.
  */
 
 int valid_url(const char *str)
 {
     const unsigned char *s, *colon, *host;
     static const char letters[] =
-	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
+        "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
     char domainbuf[DOMAIN_MAXLEN+1];
 
     for (s = (const unsigned char *)str; *s; s++) {
-	if (*s <= '\040')  // 040 == 0x20 == ' '
-	    return 0;
+        if (*s <= '\040')  // 040 == 0x20 == ' '
+            return 0;
     }
     s = (const unsigned char *)strstr(str, "://");
     if (!s)
-	return 0;  /* No "://" */
+        return 0;  /* No "://" */
     if (strspn(str, letters) != s - (const unsigned char *)str)
-	return 0;  /* Protocol has non-alphabetic characters */
+        return 0;  /* Protocol has non-alphabetic characters */
     host = s+3;
     colon = (const unsigned char *)strchr((const char *)host, ':');
     /* s will eventually point to the expected end of the host string */
     s = host + strcspn((const char *)host, "/");
     /* Make sure the port is valid if present. */
     if (colon && colon < s) {
-	const unsigned char *tmp;
-	int port = strtol((const char *)colon+1, (char **)&tmp, 10);
-	if (port < 1 || port > 65535 || tmp != s)
-	    return 0;  /* Invalid port number or non-numeric characters */
-	s = colon;
+        int port = (int)atolsafe((const char *)colon+1, 1, 65535);
+        if (port < 1)
+            return 0;  /* Invalid port number or non-numeric characters */
+        s = colon;
     }
     /* The string from host through s-1 must be a valid domain name.
      * Check length (must be >=1, <=DOMAIN_MAXLEN), then copy into
      * temporary buffer and check.  Also discard domain names without
      * dots in them. */
     if (s-host < 1 || s-host > DOMAIN_MAXLEN)
-	return 0;
+        return 0;
     memcpy(domainbuf, host, s-host);
     domainbuf[s-host] = 0;
     return strchr(domainbuf, '.') && valid_domain(domainbuf);
 }
 
-/*************************************************************************/
 /*************************************************************************/
 
-/* Process a string containing a number/range list in the form
- * "n1[-n2][,n3[-n4]]...", calling a caller-specified routine for each
- * number in the list.  If the callback returns -1, stop immediately.
- * Returns the sum of all nonnegative return values from the callback.
- * If `count_ret' is non-NULL, *count_ret will be set to the total number
- * of times the callback was called.
- *
- * The number list will never contain duplicates and will always be sorted
- * ascendingly. This means the callback routines don't have to worry about
- * being called twice for the same index. -TheShadow
- * Also, the only values accepted are 0-65536 (inclusive), to avoid someone
- * giving us 0-2^31 and causing freezes or out-of-memory.  Numbers outside
- * this range will be ignored.
- *
- * The callback should be of type range_callback_t, which is defined as:
- *	int (*range_callback_t)(User *u, int num, va_list args)
+/* Check whether the given E-mail address is rejected by a RejectEmail
+ * configuration directive.
  */
 
-int process_numlist(const char *numstr, int *count_ret,
-		    range_callback_t callback, User *u, ...)
+int rejected_email(const char *email)
 {
-    int n1, n2, min, max, i;
-    int retval = 0;
-    int numcount = 0;
-    va_list args;
-    static char numflag[65536/8+1];  /* 1 bit per index 0-65536 inclusive */
+    int i;
 
-    memset(numflag, 0, sizeof(numflag));
-    min = 65536;
-    max = 0;
-    va_start(args, u);
-
-    /* This algorithm ignores invalid characters, ignores a dash
-     * when it precedes a comma, and ignores everything from the
-     * end of a valid number or range to the next comma or null.
-     */
-    while (*numstr) {
-        n1 = n2 = strtol(numstr, (char **)&numstr, 10);
-        numstr += strcspn(numstr, "0123456789,-");
-        if (*numstr == '-') {
-            numstr++;
-            numstr += strcspn(numstr, "0123456789,");
-            if (isdigit(*numstr)) {
-                n2 = strtol(numstr, (char **)&numstr, 10);
-                numstr += strcspn(numstr, "0123456789,-");
-            }
+    if (!email) {
+        return 0;
+    }
+    ARRAY_FOREACH (i, RejectEmail) {
+        if (match_wild_nocase(RejectEmail[i], email)) {
+            return 1;
         }
-	if (n1 < 0)
-	    n1 = 0;
-	if (n2 > 65536)
-	    n2 = 65536;
-	if (n1 < min)
-	    min = n1;
-	if (n2 > max)
-	    max = n2;
-        while (n1 <= n2) {
-	    if ((n1&7) == 0 && n1+7 <= n2) {
-		/* Set a whole byte at once */
-		numflag[n1>>3] = 0xFF;
-		n1 += 8;
-	    } else {
-		/* Set just a single bit */
-		numflag[n1>>3] |= 1 << (n1&7);
-		n1++;
-	    }
-	}
-        numstr += strcspn(numstr, ",");
-        if (*numstr)
-            numstr++;
     }
-
-    /* Now call the callback routine for each index. */
-    numcount = 0;
-    for (i = min; i <= max; i++) {
-	va_list args_copy;
-	int res;
-
-	if (!(numflag[i>>3] & (1 << (i&7))))
-	    continue;
-	numcount++;
-	va_copy(args_copy, args);
-	res = callback(u, i, args_copy);
-	va_end(args_copy);
-	if (debug)
-	    log("debug: process_numlist: tried to do %d; result = %d", i, res);
-	if (res < 0)
-	    break;
-	retval += res;
-    }
-
-    va_end(args);
-    if (count_ret)
-        *count_ret = numcount;
-    return retval;
+    return 0;
 }
 
 /*************************************************************************/
@@ -665,16 +631,16 @@ time_t strtotime(const char *str, char **endptr)
     time_t t = 0;
 
     while (*str >= '0' && *str <= '9') {
-	if (t > MAX_TIME_T/10 || MAX_TIME_T - t*10 < *str-'0') {
-	    t = MAX_TIME_T;
-	    errno = ERANGE;
-	} else {
-	    t = t*10 + *str-'0';
-	}
-	str++;
+        if (t > MAX_TIME_T/10 || MAX_TIME_T - t*10 < *str-'0') {
+            t = MAX_TIME_T;
+            errno = ERANGE;
+        } else {
+            t = t*10 + *str-'0';
+        }
+        str++;
     }
     if (endptr)
-	*endptr = (char *)str;
+        *endptr = (char *)str;
     return t;
 }
 
@@ -697,19 +663,19 @@ int dotime(const char *s)
 
     amount = strtol(s, (char **)&s, 10);
     if (*s) {
-	char c = *s++;
-	int rest = dotime(s);
-	if (rest < 0)
-	    return -1;
-	switch (c) {
-	    case 's': return rest + amount;
-	    case 'm': return rest + amount*60;
-	    case 'h': return rest + amount*3600;
-	    case 'd': return rest + amount*86400;
-	    default : return -1;
-	}
+        char c = *s++;
+        int rest = dotime(s);
+        if (rest < 0)
+            return -1;
+        switch (c) {
+            case 's': return rest + amount;
+            case 'm': return rest + amount*60;
+            case 'h': return rest + amount*3600;
+            case 'd': return rest + amount*86400;
+            default : return -1;
+        }
     } else {
-	return amount;
+        return amount;
     }
 }
 
@@ -730,21 +696,21 @@ uint8 *pack_ip(const char *ipaddr)
     long tmp;
 
     if (!ipaddr)
-	return NULL;
+        return NULL;
     s = ipaddr;
     for (i = 0; i < 4; i++) {
-	if (i > 0 && *s++ != '.')
-	    return NULL;
-	if (isspace(*s))  /* because strtol() will skip whitespace */
-	    return NULL;
-	tmp = strtol(s, (char **)&s2, 10);
-	if (s2 == s || tmp < 0 || tmp > 255)
-	    return NULL;
-	ipbuf[i] = (uint8)tmp;
-	s = s2;
+        if (i > 0 && *s++ != '.')
+            return NULL;
+        if (isspace(*s))  /* because strtol() will skip whitespace */
+            return NULL;
+        tmp = strtol(s, (char **)&s2, 10);
+        if (s2 == s || tmp < 0 || tmp > 255)
+            return NULL;
+        ipbuf[i] = (uint8)tmp;
+        s = s2;
     }
     if (*s)
-	return NULL;
+        return NULL;
     return ipbuf;
 }
 
@@ -759,13 +725,11 @@ uint8 *pack_ip(const char *ipaddr)
 
 char *unpack_ip(const uint8 *ip)
 {
-    static char ipbuf[17];  /* 1 byte extra to catch overflow (paranoia) */
+    static char ipbuf[16];
 
     if (!ip)
-	return NULL;
+        return NULL;
     snprintf(ipbuf, sizeof(ipbuf), "%u.%u.%u.%u", ip[0], ip[1], ip[2], ip[3]);
-    if (strlen(ipbuf) > 15)
-	fatal("BUG: unpack_ip(): result too long (%s)", ipbuf);
     return ipbuf;
 }
 
@@ -785,75 +749,75 @@ uint8 *pack_ip6(const char *ipaddr)
     int i;
 
     if (!ipaddr)
-	return NULL;
+        return NULL;
 
     /* Parse the address into 16-bit words */
     s = ipaddr;
     wordnum = 0;
     if (*s == ':') {
-	words[wordnum++] = 0;
-	s++;
+        words[wordnum++] = 0;
+        s++;
     }
     while (*s) {
-	if (wordnum >= 8) {
-	    /* too many words, abort */
-	    return NULL;
-	}
-	if (*s == ':') {
-	    /* mark "::" with a -1 */
-	    words[wordnum++] = -1;
-	    s++;
-	} else {
-	    words[wordnum++] = (int)strtol(s, (char **)&t, 16);
-	    if (*t && *t != ':') {
-		/* invalid syntax */
-		return NULL;
-	    }
-	    if (*t) {
-		t++;  /* skip past delimiter */
-		if (!*t) {
-		    /* trailing ":", convert to :0000 */
-		    if (wordnum >= 8)
-			return NULL;
-		    words[wordnum++] = 0;
-		}
-	    }
-	    s = t;
-	}
+        if (wordnum >= 8) {
+            /* too many words, abort */
+            return NULL;
+        }
+        if (*s == ':') {
+            /* mark "::" with a -1 */
+            words[wordnum++] = -1;
+            s++;
+        } else {
+            words[wordnum++] = (int)strtol(s, (char **)&t, 16);
+            if (*t && *t != ':') {
+                /* invalid syntax */
+                return NULL;
+            }
+            if (*t) {
+                t++;  /* skip past delimiter */
+                if (!*t) {
+                    /* trailing ":", convert to :0000 */
+                    if (wordnum >= 8)
+                        return NULL;
+                    words[wordnum++] = 0;
+                }
+            }
+            s = t;
+        }
     }
 
     /* Expand "::" into as many zeros as needed, and make sure there
      * aren't multiple occurrences of "::" */
     for (i = 0; i < wordnum; i++) {
-	if (words[i] == -1)
-	    break;
+        if (words[i] == -1)
+            break;
     }
     if (i < wordnum) {  /* found a "::" */
-	int j, offset;
-	for (j = i+1; j < wordnum; j++) {
-	    if (words[j] == -1) {
-		/* multiple "::" */
-		return NULL;
-	    }
-	}
-	offset = 8-wordnum;
-	for (j = 7; j >= i; j--) {
-	    if (j-offset > i)
-		words[j] = words[j-offset];
-	    else
-		words[j] = 0;
-	}
-	wordnum = 8;
+        int j, offset;
+        for (j = i+1; j < wordnum; j++) {
+            if (words[j] == -1) {
+                /* multiple "::" */
+                return NULL;
+            }
+        }
+        offset = 8-wordnum;
+        for (j = 7; j >= i; j--) {
+            if (j-offset > i)
+                words[j] = words[j-offset];
+            else
+                words[j] = 0;
+        }
+        wordnum = 8;
     }
 
     /* Make sure we have exactly 8 words */
     if (wordnum != 8)
-	return NULL;
+        return NULL;
 
     /* Convert to binary and return */
     for (i = 0; i < 8; i++) {
-	ipbuf[i*2  ] = words[i] >> 8;
-	ipbuf[i*2+1] = words[i] & 255;
+        ipbuf[i*2  ] = words[i] >> 8;
+        ipbuf[i*2+1] = words[i] & 255;
     }
     return ipbuf;
 }
@@ -873,31 +837,29 @@ uint8 *pack_ip6(const char *ipaddr)
 
 char *unpack_ip6(const uint8 *ip)
 {
-    static char ipbuf[41];  /* 1 byte extra to catch overflow (paranoia) */
+    static char ipbuf[40];
     char *out, *s;
     int i;
 
     if (!ip)
-	return NULL;
+        return NULL;
 
     out = ipbuf;
     for (i = 0; i < 8; i++) {
-	/* Skip 0000 at beginning or end */
-	if ((i != 0 && i != 7) || ip[i*2] || ip[i*2+1]) {
-	    out += snprintf(out, sizeof(ipbuf)-(out-ipbuf), "%02X%02X",
-			    ip[i*2], ip[i*2+1]);
-	}
-	if (i != 7)
-	    *out++ = ':';
+        /* Skip 0000 at beginning or end */
+        if ((i != 0 && i != 7) || ip[i*2] || ip[i*2+1]) {
+            out += snprintf(out, sizeof(ipbuf)-(out-ipbuf), "%02X%02X",
+                            ip[i*2], ip[i*2+1]);
+        }
+        if (i != 7)
+            *out++ = ':';
     }
-    if (strlen(ipbuf) > 39)
-	fatal("BUG: unpack_ip6(): result too long (%s)", ipbuf);
     if ((s = strstr(ipbuf,":0000:")) != NULL) {
-	/* Compress zeros */
-	memmove(s+1, s+5, strlen(s+5)+1);
-	s++;
-	while (strncmp(s,":0000:",6) == 0)
-	    memmove(s, s+5, strlen(s+5)+1);
+        /* Compress zeros */
+        memmove(s+1, s+5, strlen(s+5)+1);
+        s++;
+        while (strncmp(s,":0000:",6) == 0)
+            memmove(s, s+5, strlen(s+5)+1);
     }
     return ipbuf;
 }
@@ -905,68 +867,6 @@ char *unpack_ip6(const uint8 *ip)
 /*************************************************************************/
 /*************************************************************************/
 
-/* Lock the data directory if possible; return nonzero on success, zero on
- * failure (data directory already locked or cannot create lock file).
- * On failure, errno will be EEXIST if the directory was already locked or
- * a value other than EEXIST if an error occurred creating the lock file.
- *
- * This does not attempt to correct for NFS brokenness w.r.t. O_EXCL and
- * will contain a race condition when used on an NFS filesystem (or any
- * other filesystem which does not support O_EXCL properly).
- */
-
-int lock_data(void)
-{
-    int fd;
-
-    errno = 0;
-    fd = open(LockFilename, O_WRONLY | O_CREAT | O_EXCL, 0);
-    if (fd >= 0) {
-	close(fd);
-	return 1;
-    }
-    return 0;
-}
-
-/*************************************************************************/
-
-/* Check whether the data directory is locked without actually attempting
- * to lock it.  Returns 1 if locked, 0 if not, or -1 if an error occurred
- * while trying to check (in which case errno will be set to an appropriate
- * value, i.e. whatever access() returned).
- */
-
-int is_data_locked(void)
-{
-    errno = 0;
-    if (access(LockFilename, F_OK) == 0)
-	return 1;
-    if (errno == ENOENT)
-	return 0;
-    return -1;
-}
-
-/*************************************************************************/
-
-/* Unlock the data directory.  Assumes we locked it in the first place.
- * Returns a positive nonzero value on success, zero on failure (unable to
- * remove the lock file), or -1 if the lock file didn't exist in the first
- * place (possibly because it was removed by another (misbehaving) program).
- */
-
-int unlock_data(void)
-{
-    errno = 0;
-    if (unlink(LockFilename) == 0)
-	return 1;
-    if (errno == ENOENT)
-	return -1;
-    return 0;
-}
-
-/*************************************************************************/
-/*************************************************************************/
-
 /* Encode buffer `in' of size `insize' to buffer `out' of size `outsize'
  * using base64, appending a trailing null.  Returns the number of bytes
  * required by the encoded string.  (The amount of space needed to store
@@ -978,7 +878,7 @@ int unlock_data(void)
  */
 
 static const char base64_chars[] =
-	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+        "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
 int encode_base64(const void *in, int insize, char *out, int outsize)
 {
@@ -987,52 +887,52 @@ int encode_base64(const void *in, int insize, char *out, int outsize)
     int inpos, outpos;
 
     if (insize < 0 || outsize < 0)
-	return -1;
+        return -1;
     if (outsize == 0)
-	return required;
+        return required;
     if (!out)
-	return -1;
+        return -1;
     if (insize == 0) {
-	/* outsize is at least 1 */
-	*out = 0;
-	return 1;
+        /* outsize is at least 1 */
+        *out = 0;
+        return 1;
     }
     if (!in)
-	return -1;
+        return -1;
 
     outsize--;  /* leave room for trailing \0 */
 
     /* Actually do the encoding */
     outpos = 0;
     for (inpos = 0; inpos < insize; inpos += 3) {
-	uint8 i0, i1, i2;
-	char o0, o1, o2, o3;
-	i0 = inp[inpos];
-	o0 = base64_chars[i0>>2];
-	if (inpos+1 < insize) {
-	    i1 = inp[inpos+1];
-	    o1 = base64_chars[(i0&3)<<4 | i1>>4];
-	    if (inpos+2 < insize) {
-		i2 = inp[inpos+2];
-		o2 = base64_chars[(i1&15)<<2 | i2>>6];
-		o3 = base64_chars[i2&63];
-	    } else {
-		o2 = base64_chars[(i1&15)<<2];
-		o3 = '=';
-	    }
-	} else {
-	    o1 = base64_chars[(i0&3)<<4];
-	    o2 = '=';
-	    o3 = '=';
-	}
-	if (outpos < outsize)
-	    out[outpos++] = o0;
-	if (outpos < outsize)
-	    out[outpos++] = o1;
-	if (outpos < outsize)
-	    out[outpos++] = o2;
-	if (outpos < outsize)
-	    out[outpos++] = o3;
+        uint8 i0, i1, i2;
+        char o0, o1, o2, o3;
+        i0 = inp[inpos];
+        o0 = base64_chars[i0>>2];
+        if (inpos+1 < insize) {
+            i1 = inp[inpos+1];
+            o1 = base64_chars[(i0&3)<<4 | i1>>4];
+            if (inpos+2 < insize) {
+                i2 = inp[inpos+2];
+                o2 = base64_chars[(i1&15)<<2 | i2>>6];
+                o3 = base64_chars[i2&63];
+            } else {
+                o2 = base64_chars[(i1&15)<<2];
+                o3 = '=';
+            }
+        } else {
+            o1 = base64_chars[(i0&3)<<4];
+            o2 = '=';
+            o3 = '=';
+        }
+        if (outpos < outsize)
+            out[outpos++] = o0;
+        if (outpos < outsize)
+            out[outpos++] = o1;
+        if (outpos < outsize)
+            out[outpos++] = o2;
+        if (outpos < outsize)
+            out[outpos++] = o3;
     }
 
     /* Terminate the string and return; outpos is constrained above to
@@ -1078,54 +978,192 @@ int decode_base64(const char *in, void *out, int outsize)
     int outpos;
 
     if (!in || outsize < 0)
-	return -1;
+        return -1;
 
     outpos = 0;
     while (*in) {
-	int i0, i1, i2, i3;
-	i0 = *in++;
-	if (*in) {
-	    i1 = *in++;
-	    if (*in) {
-		i2 = *in++;
-		if (*in) {
-		    i3 = *in++;
-		} else {
-		    i3 = 0;
-		}
-	    } else {
-		i2 = 0;
-		i3 = 0;
-	    }
-	} else {
-	    i1 = 0;
-	    i2 = 0;
-	    i3 = 0;
-	}
-	i0 = base64_array[(int)i0 & 255];
-	i1 = base64_array[(int)i1 & 255];
-	i2 = base64_array[(int)i2 & 255];
-	i3 = base64_array[(int)i3 & 255];
-	if (i0 < 0 || i1 < 0)
-	    break;
-	/* Only store if buffer space is available; increment outpos anyway
-	 * to keep track of total space required (for return value) */
-	if (outpos < outsize)
-	    outp[outpos] = i0<<2 | i1>>4;
-	outpos++;
-	if (i2 < 0)
-	    break;
-	if (outpos < outsize)
-	    outp[outpos] = (i1&15)<<4 | i2>>2;
-	outpos++;
-	if (i3 < 0)
-	    break;
-	if (outpos < outsize)
-	    outp[outpos] = (i2&3)<<6 | i3;
-	outpos++;
+        int i0, i1, i2, i3;
+        i0 = *in++;
+        if (*in) {
+            i1 = *in++;
+            if (*in) {
+                i2 = *in++;
+                if (*in) {
+                    i3 = *in++;
+                } else {
+                    i3 = 0;
+                }
+            } else {
+                i2 = 0;
+                i3 = 0;
+            }
+        } else {
+            i1 = 0;
+            i2 = 0;
+            i3 = 0;
+        }
+        i0 = base64_array[(int)i0 & 255];
+        i1 = base64_array[(int)i1 & 255];
+        i2 = base64_array[(int)i2 & 255];
+        i3 = base64_array[(int)i3 & 255];
+        if (i0 < 0 || i1 < 0)
+            break;
+        /* Only store if buffer space is available; increment outpos anyway
+         * to keep track of total space required (for return value) */
+        if (outpos < outsize)
+            outp[outpos] = i0<<2 | i1>>4;
+        outpos++;
+        if (i2 < 0)
+            break;
+        if (outpos < outsize)
+            outp[outpos] = (i1&15)<<4 | i2>>2;
+        outpos++;
+        if (i3 < 0)
+            break;
+        if (outpos < outsize)
+            outp[outpos] = (i2&3)<<6 | i3;
+        outpos++;
     }
 
     return outpos;
 }
 
 /*************************************************************************/
+/*************************************************************************/
+
+/* Process a string containing a number/range list in the form
+ * "n1[-n2][,n3[-n4]]...", calling a caller-specified routine for each
+ * number in the list.  If the callback returns -1, stop immediately.
+ * Returns the sum of all nonnegative return values from the callback.
+ * If `count_ret' is non-NULL, *count_ret will be set to the total number
+ * of times the callback was called.
+ *
+ * The number list will never contain duplicates and will always be sorted
+ * ascendingly. This means the callback routines don't have to worry about
+ * being called twice for the same index. -TheShadow
+ * Also, the only values accepted are 0-65536 (inclusive), to avoid someone
+ * giving us 0-2^31 and causing freezes or out-of-memory.  Numbers outside
+ * this range will be ignored.
+ *
+ * The callback should be of type range_callback_t, which is defined as:
+ *      int (*range_callback_t)(User *u, int num, va_list args)
+ */
+
+int process_numlist(const char *numstr, int *count_ret,
+                    range_callback_t callback, ...)
+{
+    int n1, n2, min, max, i;
+    int retval = 0;
+    int numcount = 0;
+    va_list args;
+    static uint8 numflag[65536/8+1];  /* 1 bit per index 0-65536 inclusive */
+
+    memset(numflag, 0, sizeof(numflag));
+    min = 65536;
+    max = 0;
+    va_start(args, callback);
+
+    /* This algorithm ignores invalid characters, ignores a dash
+     * when it precedes a comma, and ignores everything from the
+     * end of a valid number or range to the next comma or null.
+     */
+    while (*numstr) {
+        n1 = n2 = strtol(numstr, (char **)&numstr, 10);
+        numstr += strcspn(numstr, "0123456789,-");
+        if (*numstr == '-') {
+            numstr++;
+            numstr += strcspn(numstr, "0123456789,");
+            if (isdigit(*numstr)) {
+                n2 = strtol(numstr, (char **)&numstr, 10);
+                numstr += strcspn(numstr, "0123456789,-");
+            }
+        }
+        if (n1 < 0)
+            n1 = 0;
+        if (n2 > 65536)
+            n2 = 65536;
+        if (n1 < min)
+            min = n1;
+        if (n2 > max)
+            max = n2;
+        while (n1 <= n2) {
+            if ((n1&7) == 0 && n1+7 <= n2) {
+                /* Set a whole byte at once */
+                numflag[n1>>3] = 0xFF;
+                n1 += 8;
+            } else {
+                /* Set just a single bit */
+                numflag[n1>>3] |= 1 << (n1&7);
+                n1++;
+            }
+        }
+        numstr += strcspn(numstr, ",");
+        if (*numstr)
+            numstr++;
+    }
+
+    /* Now call the callback routine for each index. */
+    numcount = 0;
+    for (i = min; i <= max; i++) {
+        va_list args_copy;
+        int res;
+        if (!(numflag[i>>3] & (1 << (i&7))))
+            continue;
+        numcount++;
+        va_copy(args_copy, args);
+        res = callback(i, args_copy);
+        va_end(args_copy);
+        if (res < 0)
+            break;
+        retval += res;
+    }
+
+    va_end(args);
+    if (count_ret)
+        *count_ret = numcount;
+    return retval;
+}
+
+/*************************************************************************/
+/*************************************************************************/
+
+/* atolsafe:  Convert a string in base 10 to a long int, ensuring that the
+ *            string contains no invalid characters and that the result is
+ *            within a specified range (>=min && <=max).  Returns min-1 on
+ *            error.  errno is set to EINVAL if the string is not a valid
+ *            number, ERANGE if the value is outside the range [min..max],
+ *            and left unmodified otherwise.
+ */
+
+long atolsafe(const char *s, long min, long max)
+{
+    int errno_save = errno;
+    long v;
+
+    if (!s || !*s)
+        return min-1;
+    errno = 0;
+    v = strtol(s, (char **)&s, 10);
+    if (*s) {
+        errno = EINVAL;
+        return min-1;
+    }
+    if (errno == ERANGE || v < min || v > max) {
+        errno = ERANGE;
+        return min-1;
+    }
+    errno = errno_save;
+    return v;
+}
+
+/*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
