@@ -1,9 +1,9 @@
 /* ChanServ internal utility routines.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -12,6 +12,7 @@
  * modules/programs:
  *    new_channelinfo()
  *    free_channelinfo()
+ *    reset_levels()
  * This file should be #include'd in the file making use of the routines.
  */
 
@@ -35,14 +36,6 @@
 
 #endif
 
-/*************************************************************************/
-
-#ifndef STANDALONE_CHANSERV
-
-static Module *module;
-
-#endif
-
 /*************************************************************************/
 /************************ Global utility routines ************************/
 /*************************************************************************/
@@ -53,7 +46,7 @@ EXPORT_FUNC(new_channelinfo)
 STANDALONE_STATIC ChannelInfo *new_channelinfo(void)
 {
     ChannelInfo *ci = scalloc(sizeof(ChannelInfo), 1);
-    ci->memos.memomax = MEMOMAX_DEFAULT;
+    reset_levels(ci);
     return ci;
 }
 
@@ -67,87 +60,41 @@ STANDALONE_STATIC void free_channelinfo(ChannelInfo *ci)
     int i;
 
     if (ci) {
-	free(ci->desc);
-	free(ci->url);
-	free(ci->email);
-	free(ci->last_topic);
-	if (ci->suspendinfo)
-	    free_suspendinfo(ci->suspendinfo);
-	free(ci->levels);
-	free(ci->access);
-	ARRAY_FOREACH (i, ci->akick) {
-	    free(ci->akick[i].mask);
-	    free(ci->akick[i].reason);
-	}
-	free(ci->akick);
-	free(ci->mlock_key);
-	free(ci->mlock_link);
-	free(ci->mlock_flood);
-	free(ci->entry_message);
-	if (ci->memos.memos) {
-	    ARRAY_FOREACH (i, ci->memos.memos)
-		free(ci->memos.memos[i].text);
-	    free(ci->memos.memos);
-	}
-	free(ci);
+        clear_password(&ci->founderpass);
+        free(ci->desc);
+        free(ci->url);
+        free(ci->email);
+        free(ci->last_topic);
+        free(ci->suspend_reason);
+        free(ci->access);
+        ARRAY_FOREACH (i, ci->akick) {
+            free(ci->akick[i].mask);
+            free(ci->akick[i].reason);
+        }
+        free(ci->akick);
+        free(ci->mlock.key);
+        free(ci->mlock.link);
+        free(ci->mlock.flood);
+        free(ci->entry_message);
+        free(ci);
     }  /* if (ci) */
 }
 
 /*************************************************************************/
 
-#ifndef STANDALONE_CHANSERV  /* to the end of the file */
+/* Reset channel access level values to their default state. */
+
+EXPORT_FUNC(reset_levels)
+STANDALONE_STATIC void reset_levels(ChannelInfo *ci)
+{
+    int i;
+    for (i = 0; i < CA_SIZE; i++)
+        ci->levels[i] = ACCLEV_DEFAULT;
+}
 
 /*************************************************************************/
 
-/* Check whether the given channel (or its suspension) should be expired,
- * and do the expiration if so.  Return 1 if the channel was deleted, else 0.
- */
-
-EXPORT_FUNC(check_expire_channel)
-int check_expire_channel(ChannelInfo *ci)
-{
-    time_t now = time(NULL);
-    Channel *c = ci->c;
-
-    /* Don't bother updating last used time unless it's been a while */
-    if (c && CSExpire && now >= ci->last_used + CSExpire/2) {
-	struct c_userlist *cu;
-	LIST_FOREACH (cu, c->users) {
-	    if (check_access(cu->user, ci, CA_AUTOOP)) {
-		if (debug >= 2)
-		    module_log("debug: updating last used time for %s",
-			       ci->name);
-		ci->last_used = time(NULL);
-		put_channelinfo(ci);
-		break;
-	    }
-	}
-    }
-
-    if (CSExpire
-     && now >= ci->last_used + CSExpire
-     && !(ci->flags & (CI_VERBOTEN | CI_NOEXPIRE))
-     && !ci->suspendinfo
-    ) {
-	module_log("Expiring channel %s", ci->name);
-	if (chanmode_reg && c) {
-	    c->mode &= ~chanmode_reg;
-	    /* Send this out immediately, no set_cmode() delay */
-	    send_cmode_cmd(s_ChanServ, ci->name, "-%s",
-		     mode_flags_to_string(chanmode_reg, MODE_CHANNEL));
-	}
-	delchan(ci);
-	return 1;
-    }
-
-    if (ci->suspendinfo && ci->suspendinfo->expires
-     && now >= ci->suspendinfo->expires
-    ) {
-	module_log("Expiring suspension for %s", ci->name);
-	unsuspend_channel(ci, 1);
-    }
-    return 0;
-}
+#ifndef STANDALONE_CHANSERV  /* to the end of the file */
 
 /*************************************************************************/
 
@@ -158,18 +105,18 @@ int check_expire_channel(ChannelInfo *ci)
  */
 
 EXPORT_FUNC(check_channel_limit)
-int check_channel_limit(NickGroupInfo *ngi, int *max_ret)
+int check_channel_limit(const NickGroupInfo *ngi, int *max_ret)
 {
     register int max, count;
 
     max = ngi->channelmax;
     if (max == CHANMAX_DEFAULT)
-	max = CSMaxReg;
+        max = CSMaxReg;
     else if (max == CHANMAX_UNLIMITED)
-	max = MAX_CHANNELCOUNT;
+        max = MAX_CHANNELCOUNT;
     count = ngi->channels_count;
     if (max_ret)
-	*max_ret = max;
+        *max_ret = max;
     return count<max ? -1 : count==max ? 0 : 1;
 }
 
@@ -186,9 +133,9 @@ ChannelInfo *makechan(const char *chan)
     ChannelInfo *ci;
 
     ci = scalloc(sizeof(ChannelInfo), 1);
-    strscpy(ci->name, chan, CHANMAX);
+    strbcpy(ci->name, chan);
     ci->time_registered = time(NULL);
-    reset_levels(ci, 0);
+    reset_levels(ci);
     return add_channelinfo(ci);
 }
 
@@ -205,20 +152,27 @@ int delchan(ChannelInfo *ci)
     /* Remove channel from founder's owned-channel count */
     uncount_chan(ci);
 
-    /* Clear link from channel record if it exists */
-    c = get_channel(ci->name);
-    if (c)
-	c->ci = NULL;
+    /* Clear link (and "registered" mode) from channel record if it exists */
+    c = ci->c;
+    if (c) {
+        c->ci = NULL;
+        if (chanmode_reg) {
+            c->mode &= ~chanmode_reg;
+            /* Send this out immediately, no set_cmode() delay */
+            send_cmode_cmd(s_ChanServ, ci->name, "-%s",
+                           mode_flags_to_string(chanmode_reg, MODE_CHANNEL));
+        }
+    }
 
     /* Clear channel from users' identified-channel lists */
     for (u = first_user(); u; u = next_user()) {
-	struct u_chaninfolist *uc, *next;
-	LIST_FOREACH_SAFE (uc, u->id_chans, next) {
-	    if (irc_stricmp(uc->chan, ci->name) == 0) {
-		LIST_REMOVE(uc, u->id_chans);
-		free(uc);
-	    }
-	}
+        struct u_chaninfolist *uc, *next;
+        LIST_FOREACH_SAFE (uc, u->id_chans, next) {
+            if (irc_stricmp(uc->chan, ci->name) == 0) {
+                LIST_REMOVE(uc, u->id_chans);
+                free(uc);
+            }
+        }
     }
 
     /* Now actually delete record */
@@ -233,21 +187,21 @@ int delchan(ChannelInfo *ci)
  * founder's list of owned channels (ngi->channels).
  */
 
-void count_chan(ChannelInfo *ci)
+void count_chan(const ChannelInfo *ci)
 {
     NickGroupInfo *ngi = ci->founder ? get_ngi_id(ci->founder) : NULL;
 
     if (!ngi)
-	return;
+        return;
     /* Be paranoid--this could overflow in extreme cases, though we check
      * for that elsewhere as well. */
     if (ngi->channels_count >= MAX_CHANNELCOUNT) {
-	module_log("count BUG: overflow in ngi->channels_count for %u (%s)"
-		   " on %s", ngi->id, ngi_mainnick(ngi), ci->name);
-	return;
+        module_log("count BUG: overflow in ngi->channels_count for %u (%s)"
+                   " on %s", ngi->id, ngi_mainnick(ngi), ci->name);
+        return;
     }
     ARRAY_EXTEND(ngi->channels);
-    strscpy(ngi->channels[ngi->channels_count-1], ci->name, CHANMAX);
+    strbcpy(ngi->channels[ngi->channels_count-1], ci->name);
     put_nickgroupinfo(ngi);
 }
 
@@ -255,20 +209,20 @@ void count_chan(ChannelInfo *ci)
 
 /* Mark the given channel as no longer owned by its founder. */
 
-void uncount_chan(ChannelInfo *ci)
+void uncount_chan(const ChannelInfo *ci)
 {
     NickGroupInfo *ngi = ci->founder ? get_ngi_id(ci->founder) : NULL;
     int i;
 
     if (!ngi)
-	return;
+        return;
     ARRAY_SEARCH_PLAIN(ngi->channels, ci->name, irc_stricmp, i);
     if (i >= ngi->channels_count) {
-	module_log("uncount BUG: channel not found in channels[] for %u (%s)"
-		   " on %s", ngi->id,
-		   ngi->nicks_count ? ngi_mainnick(ngi) : "<unknown>",
-		   ci->name);
-	return;
+        module_log("uncount BUG: channel not found in channels[] for %u (%s)"
+                   " on %s", ngi->id,
+                   ngi->nicks_count ? ngi_mainnick(ngi) : "<unknown>",
+                   ci->name);
+        return;
     }
     ARRAY_REMOVE(ngi->channels, i);
     put_nickgroupinfo(ngi);
@@ -278,17 +232,17 @@ void uncount_chan(ChannelInfo *ci)
 
 /* Does the given user have founder access to the channel? */
 
-int is_founder(User *user, ChannelInfo *ci)
+int is_founder(const User *user, const ChannelInfo *ci)
 {
-    if (!ci || (ci->flags&CI_VERBOTEN) || ci->suspendinfo || !valid_ngi(user))
-	return 0;
+    if (!ci || (ci->flags & (CF_VERBOTEN | CF_SUSPENDED)) || !valid_ngi(user))
+        return 0;
     if (user->ngi->id == ci->founder) {
-	if ((user_identified(user) ||
-		 (user_recognized(user) && !(ci->flags & CI_SECURE))))
-	    return 1;
+        if ((user_identified(user) ||
+                 (user_recognized(user) && !(ci->flags & CF_SECURE))))
+            return 1;
     }
     if (is_identified(user, ci))
-	return 1;
+        return 1;
     return 0;
 }
 
@@ -296,15 +250,15 @@ int is_founder(User *user, ChannelInfo *ci)
 
 /* Has the given user password-identified as founder for the channel? */
 
-int is_identified(User *user, ChannelInfo *ci)
+int is_identified(const User *user, const ChannelInfo *ci)
 {
     struct u_chaninfolist *c;
 
     if (!ci)
-	return 0;
+        return 0;
     LIST_FOREACH (c, user->id_chans) {
-	if (irc_stricmp(c->chan, ci->name) == 0)
-	    return 1;
+        if (irc_stricmp(c->chan, ci->name) == 0)
+            return 1;
     }
     return 0;
 }
@@ -317,10 +271,10 @@ void restore_topic(Channel *c)
 {
     ChannelInfo *ci = c->ci;
 
-    if (ci && (ci->flags & CI_KEEPTOPIC) && ci->last_topic && *ci->last_topic){
-	set_topic(s_ChanServ, c, ci->last_topic,
-		  *ci->last_topic_setter ? ci->last_topic_setter : s_ChanServ,
-		  ci->last_topic_time);
+    if (ci && (ci->flags & CF_KEEPTOPIC) && ci->last_topic && *ci->last_topic){
+        set_topic(s_ChanServ, c, ci->last_topic,
+                  *ci->last_topic_setter ? ci->last_topic_setter : s_ChanServ,
+                  ci->last_topic_time);
     }
 }
 
@@ -329,31 +283,31 @@ void restore_topic(Channel *c)
 /* Record a channel's topic in its ChannelInfo structure. */
 
 void record_topic(ChannelInfo *ci, const char *topic,
-		  const char *setter, time_t topic_time)
+                  const char *setter, time_t topic_time)
 {
-    if (readonly || !ci)
-	return;
+    if (!ci)
+        return;
     free(ci->last_topic);
     if (*topic)
-	ci->last_topic = sstrdup(topic);
+        ci->last_topic = sstrdup(topic);
     else
-	ci->last_topic = NULL;
-    strscpy(ci->last_topic_setter, setter, NICKMAX);
+        ci->last_topic = NULL;
+    strbcpy(ci->last_topic_setter, setter);
     ci->last_topic_time = topic_time;
-    put_channelinfo(ci);
 }
 
 /*************************************************************************/
 
-/* Create a new SuspendInfo structure and associate it with the given
- * channel. */
+/* Mark the given channel as suspended. */
 
 void suspend_channel(ChannelInfo *ci, const char *reason,
-		     const char *who, const time_t expires)
+                     const char *who, const time_t expires)
 {
-    SuspendInfo *si = new_suspendinfo(who, sstrdup(reason), expires);
-    ci->suspendinfo = si;
-    put_channelinfo(ci);
+    strbcpy(ci->suspend_who, who);
+    ci->suspend_reason  = sstrdup(reason);
+    ci->suspend_time    = time(NULL);
+    ci->suspend_expires = expires;
+    ci->flags |= CF_SUSPENDED;
 }
 
 /*************************************************************************/
@@ -368,21 +322,24 @@ void unsuspend_channel(ChannelInfo *ci, int set_time)
 {
     time_t now = time(NULL);
 
-    if (!ci->suspendinfo) {
-	module_log("unsuspend_channel() called on non-suspended channel %s",
-		   ci->name);
-	return;
+    if (!(ci->flags & CF_SUSPENDED)) {
+        module_log("unsuspend_channel() called on non-suspended channel %s",
+                   ci->name);
+        return;
     }
-    free_suspendinfo(ci->suspendinfo);
-    ci->suspendinfo = NULL;
+    ci->flags &= ~CF_SUSPENDED;
+    free(ci->suspend_reason);
+    memset(ci->suspend_who, 0, sizeof(ci->suspend_who));
+    ci->suspend_reason  = NULL;
+    ci->suspend_time    = 0;
+    ci->suspend_expires = 0;
     if (set_time && CSExpire && CSSuspendGrace
      && (now - ci->last_used >= CSExpire - CSSuspendGrace)
     ) {
-	ci->last_used = now - CSExpire + CSSuspendGrace;
-	module_log("unsuspend: Altering last_used time for %s to %ld",
-		   ci->name, (long)ci->last_used);
+        ci->last_used = now - CSExpire + CSSuspendGrace;
+        module_log("unsuspend: Altering last_used time for %s to %ld",
+                   ci->name, (long)ci->last_used);
     }
-    put_channelinfo(ci);
 }
 
 /*************************************************************************/
@@ -394,9 +351,9 @@ void chan_bad_password(User *u, ChannelInfo *ci)
     bad_password(s_ChanServ, u, ci->name);
     ci->bad_passwords++;
     if (BadPassWarning && ci->bad_passwords == BadPassWarning) {
-	wallops(s_ChanServ, "\2Warning:\2 Repeated bad password attempts"
-	                    " for channel %s (last attempt by user %s)",
-		ci->name, u->nick);
+        wallops(s_ChanServ, "\2Warning:\2 Repeated bad password attempts"
+                            " for channel %s (last attempt by user %s)",
+                ci->name, u->nick);
     }
 }
 
@@ -410,8 +367,8 @@ ChanOpt *chanopt_from_name(const char *optname)
 {
     int i;
     for (i = 0; chanopts[i].name; i++) {
-	if (stricmp(chanopts[i].name, optname) == 0)
-	    return &chanopts[i];
+        if (stricmp(chanopts[i].name, optname) == 0)
+            return &chanopts[i];
     }
     return NULL;
 }
@@ -424,7 +381,7 @@ ChanOpt *chanopt_from_name(const char *optname)
  * will be overwritten on the next call.
  */
 
-char *chanopts_to_string(ChannelInfo *ci, NickGroupInfo *ngi)
+char *chanopts_to_string(const ChannelInfo *ci, const NickGroupInfo *ngi)
 {
     static char buf[BUFSIZE];
     char *end = buf;
@@ -434,36 +391,31 @@ char *chanopts_to_string(ChannelInfo *ci, NickGroupInfo *ngi)
     int i;
 
     for (i = 0; chanopts[i].name && end-buf < sizeof(buf)-1; i++) {
-	if (chanopts[i].namestr < 0)
-	    continue;
-	if (ci->flags & chanopts[i].flag) {
-	    s = getstring(ngi, chanopts[i].namestr);
-	    if (!s)
-		continue;
-	    if (need_comma)
-		end += snprintf(end, sizeof(buf)-(end-buf), "%s", commastr);
-	    end += snprintf(end, sizeof(buf)-(end-buf), "%s", s);
-	    need_comma = 1;
-	}
+        if (chanopts[i].namestr < 0)
+            continue;
+        if (ci->flags & chanopts[i].flag) {
+            s = getstring(ngi, chanopts[i].namestr);
+            if (!s)
+                continue;
+            if (need_comma)
+                end += snprintf(end, sizeof(buf)-(end-buf), "%s", commastr);
+            end += snprintf(end, sizeof(buf)-(end-buf), "%s", s);
+            need_comma = 1;
+        }
     }
     return buf;
 }
 
-/*************************************************************************/
-/*************************************************************************/
-
-int init_util(Module *my_module)
-{
-    module = my_module;
-    return 1;
-}
-
-/*************************************************************************/
-
-void exit_util()
-{
-}
-
 /*************************************************************************/
 
 #endif  /* !STANDALONE_CHANSERV */
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
