@@ -1,9 +1,9 @@
 /* RFC1459 protocol module for IRC Services.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -14,42 +14,8 @@
 
 /*************************************************************************/
 
-static Module *module;
-
 static char *NetworkDomain = NULL;
 
-/*************************************************************************/
-/************************** User/channel modes ***************************/
-/*************************************************************************/
-
-struct modedata_init {
-    uint8 mode;
-    ModeData data;
-};
-
-static const struct modedata_init new_usermodes[] = {
-};
-
-static const struct modedata_init new_chanmodes[] = {
-};
-
-static const struct modedata_init new_chanusermodes[] = {
-};
-
-static void init_modes(void)
-{
-    int i;
-
-    for (i = 0; i < lenof(new_usermodes); i++)
-	usermodes[new_usermodes[i].mode] = new_usermodes[i].data;
-    for (i = 0; i < lenof(new_chanmodes); i++)
-	chanmodes[new_chanmodes[i].mode] = new_chanmodes[i].data;
-    for (i = 0; i < lenof(new_chanusermodes); i++)
-	chanusermodes[new_chanusermodes[i].mode] = new_chanusermodes[i].data;
-
-    mode_setup();
-};
-
 /*************************************************************************/
 /************************* IRC message receiving *************************/
 /*************************************************************************/
@@ -57,15 +23,14 @@ static void init_modes(void)
 static void m_nick(char *source, int ac, char **av)
 {
     if (*source) {
-	/* Old user changing nicks. */
-	if (ac != 1) {
-	    if (debug)
-		module_log("debug: NICK message: wrong number of parameters"
-			   " (%d) for source `%s'", ac, source);
-	} else {
-	    do_nick(source, ac, av);
-	}
-	return;
+        /* Old user changing nicks. */
+        if (ac != 1) {
+            module_log_debug(1, "NICK message: wrong number of parameters"
+                             " (%d) for source `%s'", ac, source);
+        } else {
+            do_nick(source, ac, av);
+        }
+        return;
     }
 
     /* New user.  We get the information we want from the USER command, so
@@ -78,8 +43,8 @@ static void m_user(char *source, int ac, char **av)
 {
     char *new_av[7];
 
-    if (ac != 5)
-	return;
+    if (ac != 4)
+        return;
     new_av[0] = source;      /* Nickname */
     new_av[1] = (char *)"0"; /* # of hops (was in NICK command... we lose) */
     new_av[2] = (char *)"0"; /* Timestamp */
@@ -105,13 +70,13 @@ static Message rfc1459_messages[] = {
 /* Send a NICK command for a new user. */
 
 static void do_send_nick(const char *nick, const char *user, const char *host,
-			 const char *server, const char *name,
-			 const char *modes)
+                         const char *server, const char *name,
+                         const char *modes)
 {
     send_cmd(NULL, "NICK %s :1", nick);
     send_cmd(nick, "USER %s %s %s :%s", user, host, server, name);
     if (modes)
-	send_cmd(nick, "MODE %s +%s", nick, modes);
+        send_cmd(nick, "MODE %s +%s", nick, modes);
 }
 
 /*************************************************************************/
@@ -181,14 +146,14 @@ static void do_notice_all(const char *source, const char *fmt, ...)
     vsnprintf(msgbuf, sizeof(msgbuf), fmt, args);
     va_end(args);
     if (NetworkDomain) {
-	send_cmd(source, "NOTICE $*.%s :%s", NetworkDomain, msgbuf);
+        send_cmd(source, "NOTICE $*.%s :%s", NetworkDomain, msgbuf);
     } else {
-	/* Go through all common top-level domains.  If you have others,
-	 * add them here. */
-	send_cmd(source, "NOTICE $*.com :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.net :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.org :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.edu :%s", msgbuf);
+        /* Go through all common top-level domains.  If you have others,
+         * add them here. */
+        send_cmd(source, "NOTICE $*.com :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.net :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.org :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.edu :%s", msgbuf);
     }
 }
 
@@ -210,13 +175,13 @@ static void do_send_channel_cmd(const char *source, const char *fmt, ...)
 /*************************************************************************/
 
 static int do_set_topic(const char *source, Channel *c, const char *topic,
-			const char *setter, time_t t)
+                        const char *setter, time_t t)
 {
     if (setter)
-	return 0;
+        return 0;
     c->topic_time = t;
     send_cmd(source, "TOPIC %s %s :%s", c->name,
-	     c->topic_setter, c->topic ? c->topic : "");
+             c->topic_setter, c->topic ? c->topic : "");
     return 1;
 }
 
@@ -224,8 +189,6 @@ static int do_set_topic(const char *source, Channel *c, const char *topic,
 /***************************** Module stuff ******************************/
 /*************************************************************************/
 
-const int32 module_version = MODULE_VERSION_CODE;
-
 ConfigDirective module_config[] = {
     { "NetworkDomain", { { CD_STRING, 0, &NetworkDomain } } },
     { NULL }
@@ -233,29 +196,25 @@ ConfigDirective module_config[] = {
 
 /*************************************************************************/
 
-int init_module(Module *module_)
+int init_module(void)
 {
-    module = module_;
-
     protocol_name     = "RFC1459";
     protocol_version  = "";
     protocol_features = 0;
     protocol_nickmax  = 9;
 
     if (!register_messages(rfc1459_messages)) {
-	module_log("Unable to register messages");
-	exit_module(1);
-	return 0;
+        module_log("Unable to register messages");
+        exit_module(1);
+        return 0;
     }
 
     if (!add_callback(NULL, "set topic", do_set_topic)) {
-	module_log("Unable to add callbacks");
-	exit_module(1);
-	return 0;
+        module_log("Unable to add callbacks");
+        exit_module(1);
+        return 0;
     }
 
-    init_modes();
-
     send_nick          = do_send_nick;
     send_nickchange    = do_send_nickchange;
     send_namechange    = do_send_namechange;
@@ -266,6 +225,7 @@ int init_module(Module *module_)
     send_channel_cmd   = do_send_channel_cmd;
     pseudoclient_modes = "";
     enforcer_modes     = "";
+    pseudoclient_oper  = 1;
 
     return 1;
 }
@@ -275,8 +235,8 @@ int init_module(Module *module_)
 int exit_module(int shutdown)
 {
     if (!shutdown) {
-	/* Do not allow removal */
-	return 0;
+        /* Do not allow removal */
+        return 0;
     }
 
     remove_callback(NULL, "set topic", do_set_topic);
@@ -285,3 +245,13 @@ int exit_module(int shutdown)
 }
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
