@@ -1,9 +1,9 @@
 /* Undernet 2.9.x (P9) protocol module for IRC Services.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -15,8 +15,6 @@
 
 /*************************************************************************/
 
-static Module *module;
-
 static char *NetworkDomain = NULL;
 
 /*************************************************************************/
@@ -42,11 +40,11 @@ static void init_modes(void)
     int i;
 
     for (i = 0; i < lenof(new_usermodes); i++)
-	usermodes[new_usermodes[i].mode] = new_usermodes[i].data;
+        usermodes[new_usermodes[i].mode] = new_usermodes[i].data;
     for (i = 0; i < lenof(new_chanmodes); i++)
-	chanmodes[new_chanmodes[i].mode] = new_chanmodes[i].data;
+        chanmodes[new_chanmodes[i].mode] = new_chanmodes[i].data;
     for (i = 0; i < lenof(new_chanusermodes); i++)
-	chanusermodes[new_chanusermodes[i].mode] = new_chanusermodes[i].data;
+        chanusermodes[new_chanusermodes[i].mode] = new_chanusermodes[i].data;
 
     mode_setup();
 };
@@ -60,27 +58,25 @@ static void m_nick(char *source, int ac, char **av)
     /* ircu sends the server as the source for a NICK message for a new
      * user. */
     if (strchr(source, '.'))
-	*source = 0;
+        *source = 0;
 
     if (*source) {
-	/* Old user changing nicks. */
-	if (ac != 2) {
-	    if (debug)
-		module_log("debug: NICK message: wrong number of parameters"
-			   " (%d) for source `%s'", ac, source);
-	} else {
-	    do_nick(source, ac, av);
-	}
-	return;
+        /* Old user changing nicks. */
+        if (ac != 2) {
+            module_log_debug(1, "NICK message: wrong number of parameters"
+                             " (%d) for source `%s'", ac, source);
+        } else {
+            do_nick(source, ac, av);
+        }
+        return;
     }
 
     /* New user. */
 
     if (ac != 7) {
-	if (debug)
-	    module_log("debug: NICK message: wrong number of parameters (%d)"
-		       " for new user", ac);
-	return;
+        module_log_debug(1, "NICK message: wrong number of parameters (%d)"
+                         " for new user", ac);
+        return;
     }
     do_nick(source, ac, av);
 }
@@ -100,13 +96,13 @@ static Message undernet_p9_messages[] = {
 /* Send a NICK command for a new user. */
 
 static void do_send_nick(const char *nick, const char *user, const char *host,
-			 const char *server, const char *name,
-			 const char *modes)
+                         const char *server, const char *name,
+                         const char *modes)
 {
     send_cmd(ServerName, "NICK %s 1 %ld %s %s %s :%s", nick,
-	     (long)time(NULL), user, host, server, name);
+             (long)time(NULL), user, host, server, name);
     if (modes)
-	send_cmd(nick, "MODE %s +%s", nick, modes);
+        send_cmd(nick, "MODE %s +%s", nick, modes);
 }
 
 /*************************************************************************/
@@ -176,14 +172,14 @@ static void do_notice_all(const char *source, const char *fmt, ...)
     vsnprintf(msgbuf, sizeof(msgbuf), fmt, args);
     va_end(args);
     if (NetworkDomain) {
-	send_cmd(source, "NOTICE $*.%s :%s", NetworkDomain, msgbuf);
+        send_cmd(source, "NOTICE $*.%s :%s", NetworkDomain, msgbuf);
     } else {
-	/* Go through all common top-level domains.  If you have others,
-	 * add them here. */
-	send_cmd(source, "NOTICE $*.com :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.net :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.org :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.edu :%s", msgbuf);
+        /* Go through all common top-level domains.  If you have others,
+         * add them here. */
+        send_cmd(source, "NOTICE $*.com :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.net :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.org :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.edu :%s", msgbuf);
     }
 }
 
@@ -205,26 +201,26 @@ static void do_send_channel_cmd(const char *source, const char *fmt, ...)
 /*************************************************************************/
 
 static int do_set_topic(const char *source, Channel *c, const char *topic,
-			const char *setter, time_t t)
+                        const char *setter, time_t t)
 {
     if (setter)
-	return 0;
+        return 0;
     c->topic_time = t;
     send_cmd(source, "TOPIC %s %s %lu :%s", c->name, c->topic_setter,
-	     (long)c->topic_time, c->topic ? c->topic : "");
+             (long)c->topic_time, c->topic ? c->topic : "");
     return 1;
 }
 
 /*************************************************************************/
 
 static int do_send_akill(const char *username, const char *host,
-			 time_t expires, const char *who, const char *reason)
+                         time_t expires, const char *who, const char *reason)
 {
     time_t now = time(NULL);
 
     send_cmd(ServerName, "GLINE * +%s@%s %ld :%s", username, host,
-	     (long)(expires && expires > now ? expires-now : (0x7FFFFFFE)-now),
-	     reason);
+             (long)(expires && expires > now ? expires-now : (0x7FFFFFFE)-now),
+             reason);
     return 1;
 }
 
@@ -240,8 +236,6 @@ static int do_cancel_akill(const char *username, const char *host)
 /***************************** Module stuff ******************************/
 /*************************************************************************/
 
-const int32 module_version = MODULE_VERSION_CODE;
-
 ConfigDirective module_config[] = {
     { "NetworkDomain", { { CD_STRING, 0, &NetworkDomain } } },
     { NULL }
@@ -252,10 +246,10 @@ ConfigDirective module_config[] = {
 static int do_load_module(Module *mod, const char *modname)
 {
     if (strcmp(modname, "operserv/akill") == 0) {
-	if (!add_callback(mod, "send_akill", do_send_akill))
-	    module_log("Unable to add send_akill callback");
-	if (!add_callback(mod, "cancel_akill", do_cancel_akill))
-	    module_log("Unable to add cancel_akill callback");
+        if (!add_callback(mod, "send_akill", do_send_akill))
+            module_log("Unable to add send_akill callback");
+        if (!add_callback(mod, "cancel_akill", do_cancel_akill))
+            module_log("Unable to add cancel_akill callback");
     }
     return 0;
 }
@@ -269,37 +263,30 @@ static int do_unload_module(Module *mod)
 
 /*************************************************************************/
 
-int init_module(Module *module_)
+int init_module(void)
 {
-    unsigned char c;
-
-    module = module_;
-
     protocol_name     = "Undernet";
     protocol_version  = "2.9.x";
     protocol_features = 0;
     protocol_nickmax  = 9;
 
     if (!register_messages(undernet_p9_messages)) {
-	module_log("Unable to register messages");
-	exit_module(1);
-	return 0;
+        module_log("Unable to register messages");
+        exit_module(1);
+        return 0;
     }
 
     if (!add_callback(NULL, "load module", do_load_module)
      || !add_callback(NULL, "unload module", do_unload_module)
      || !add_callback(NULL, "set topic", do_set_topic)
     ) {
-	module_log("Unable to add callbacks");
-	exit_module(1);
-	return 0;
+        module_log("Unable to add callbacks");
+        exit_module(1);
+        return 0;
     }
 
     init_modes();
 
-    for (c = 'A'; c <= '}'; c++)
-	valid_nick_table[c] = 3;
-
     send_nick          = do_send_nick;
     send_nickchange    = do_send_nickchange;
     send_namechange    = do_send_namechange;
@@ -310,8 +297,9 @@ int init_module(Module *module_)
     send_channel_cmd   = do_send_channel_cmd;
     pseudoclient_modes = "";
     enforcer_modes     = "";
+    pseudoclient_oper  = 1;
 
-    setstring(OPER_BOUNCY_MODES, OPER_BOUNCY_MODES_U_LINE);
+    mapstring(OPER_BOUNCY_MODES, OPER_BOUNCY_MODES_U_LINE);
 
     return 1;
 }
@@ -321,8 +309,8 @@ int init_module(Module *module_)
 int exit_module(int shutdown)
 {
     if (!shutdown) {
-	/* Do not allow removal */
-	return 0;
+        /* Do not allow removal */
+        return 0;
     }
 
     remove_callback(NULL, "set topic", do_set_topic);
@@ -333,3 +321,13 @@ int exit_module(int shutdown)
 }
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
