@@ -1,9 +1,9 @@
 /* Statistical information.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -12,10 +12,11 @@
 
 /*************************************************************************/
 
+#if 0  // not implemented
 typedef struct minmax_ MinMax;
 struct minmax_ {
         int min, max;
-	time_t mintime, maxtime;
+        time_t mintime, maxtime;
 };
 
 
@@ -23,12 +24,11 @@ typedef struct minmaxhistory_ MinMaxHistory;
 struct minmaxhistory_ {
         MinMax hour, today, week, month, ever;
 };
+#endif
 
 
 struct serverstats_ {
-    ServerStats *next, *prev;	/* Use to navigate the entire server list */
-    int modified;
-    int locked;
+    ServerStats *next, *prev;   /* Use to navigate the entire server list */
 
     char *name;                 /* Server's name */
 
@@ -37,10 +37,10 @@ struct serverstats_ {
     MinMaxHistory mm_opers;
 #endif
 
-    time_t t_join;		/* Time server joined us. 0 == not here. */
-    time_t t_quit;		/* Time server quit. */
+    time_t t_join;              /* Time server joined us. 0 == not here. */
+    time_t t_quit;              /* Time server quit. */
 
-    char *quit_message;		/* Server's last quit message */
+    char *quit_message;         /* Server's last quit message */
 
 #if 0
     int indirectsplits;         /* Times this server has split from view due to
@@ -51,27 +51,34 @@ struct serverstats_ {
 
     /* Online-only information: */
 
-    int usercnt;		/* Current number of users on server */
-    int opercnt;		/* Current number of opers on server */
+    int usercnt;                /* Current number of users on server */
+    int opercnt;                /* Current number of opers on server */
 };
 
 /*************************************************************************/
 
-/* Imports: */
+/* Exports: */
+
 E ServerStats *add_serverstats(ServerStats *ss);
 E void del_serverstats(ServerStats *ss);
 E ServerStats *get_serverstats(const char *servername);
-E void put_serverstats(ServerStats *ss);
+E ServerStats *put_serverstats(ServerStats *ss);
 E ServerStats *first_serverstats(void);
 E ServerStats *next_serverstats(void);
-E int open_statserv_db(const char *dbname);
-E int sync_statserv_db(const char *dbname);
-E int close_statserv_db(const char *dbname);
 
-/* Exports: */
 E ServerStats *new_serverstats(const char *servername);
 E void free_serverstats(ServerStats *serverstats);
 
 /*************************************************************************/
 
-#endif	/* STATISTICS_H */
+#endif  /* STATISTICS_H */
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
