@@ -1,16 +1,15 @@
 /* Main processing code for Services.
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
 #include "services.h"
 #include "modules.h"
 #include "messages.h"
-#include "ignore.h"
 
 static int cb_recvmsg = -1;
 
@@ -26,7 +25,7 @@ static int cb_recvmsg = -1;
  *             RFC.  Destroys the buffer by side effect.
  */
 
-static char **sbargv = NULL;
+static char **sbargv = NULL;  /* File scope so process_cleanup() can free it */
 
 int split_buf(char *buf, char ***argv_ptr, int colon_special)
 {
@@ -35,28 +34,28 @@ int split_buf(char *buf, char ***argv_ptr, int colon_special)
     char *s;
 
     if (!sbargv)
-	sbargv = smalloc(sizeof(char *) * argvsize);
+        sbargv = smalloc(sizeof(char *) * argvsize);
     argc = 0;
     while (*buf) {
-	if (argc == argvsize) {
-	    argvsize += 8;
-	    sbargv = srealloc(sbargv, sizeof(char *) * argvsize);
-	}
-	if (*buf == ':' && colon_special) {
-	    sbargv[argc++] = buf+1;
-	    *buf = 0;
-	} else {
-	    s = strpbrk(buf, " ");
-	    if (s) {
-		*s++ = 0;
-		while (*s == ' ')
-		    s++;
-	    } else {
-		s = buf + strlen(buf);
-	    }
-	    sbargv[argc++] = buf;
-	    buf = s;
-	}
+        if (argc == argvsize) {
+            argvsize += 8;
+            sbargv = srealloc(sbargv, sizeof(char *) * argvsize);
+        }
+        if (*buf == ':' && colon_special) {
+            sbargv[argc++] = buf+1;
+            *buf = 0;
+        } else {
+            s = strpbrk(buf, " ");
+            if (s) {
+                *s++ = 0;
+                while (*s == ' ')
+                    s++;
+            } else {
+                s = buf + strlen(buf);
+            }
+            sbargv[argc++] = buf;
+            buf = s;
+        }
     }
     *argv_ptr = sbargv;
     return argc;
@@ -67,10 +66,10 @@ int split_buf(char *buf, char ***argv_ptr, int colon_special)
 
 int process_init(int ac, char **av)
 {
-    cb_recvmsg = register_callback(NULL, "receive message");
+    cb_recvmsg = register_callback("receive message");
     if (cb_recvmsg < 0) {
-	log("process_init: register_callback() failed\n");
-	return 0;
+        log("process_init: register_callback() failed\n");
+        return 0;
     }
     return 1;
 }
@@ -79,7 +78,7 @@ int process_init(int ac, char **av)
 
 void process_cleanup(void)
 {
-    unregister_callback(NULL, cb_recvmsg);
+    unregister_callback(cb_recvmsg);
     free(sbargv);
     sbargv = NULL;
 }
@@ -89,62 +88,57 @@ void process_cleanup(void)
 /* process:  Main processing routine.  Takes the string in inbuf (global
  *           variable) and does something appropriate with it. */
 
-void process()
+void process(void)
 {
     char source[64];
     char cmd[64];
-    char buf[512];		/* Longest legal IRC command line */
+    char buf[512];              /* Longest legal IRC command line */
     char *s;
-    int ac;			/* Parameters for the command */
+    int ac;                     /* Parameters for the command */
     char **av;
 
 
     /* If debugging, log the buffer. */
-    if (debug)
-	log("debug: Received: %s", inbuf);
+    log_debug(1, "Received: %s", inbuf);
 
     /* First make a copy of the buffer so we have the original in case we
      * crash - in that case, we want to know what we crashed on. */
-    strscpy(buf, inbuf, sizeof(buf));
+    strbcpy(buf, inbuf);
 
     /* Split the buffer into pieces. */
     if (*buf == ':') {
-	s = strpbrk(buf, " ");
-	if (!s)
-	    return;
-	*s = 0;
-	while (isspace(*++s))
-	    ;
-	strscpy(source, buf+1, sizeof(source));
-	strmove(buf, s);
+        s = strpbrk(buf, " ");
+        if (!s)
+            return;
+        *s = 0;
+        while (isspace(*++s))
+            ;
+        strbcpy(source, buf+1);
+        strmove(buf, s);
     } else {
-	*source = 0;
+        *source = 0;
     }
     if (!*buf)
-	return;
+        return;
     s = strpbrk(buf, " ");
     if (s) {
-	*s = 0;
-	while (isspace(*++s))
-	    ;
+        *s = 0;
+        while (isspace(*++s))
+            ;
     } else
-	s = buf + strlen(buf);
-    strscpy(cmd, buf, sizeof(cmd));
+        s = buf + strlen(buf);
+    strbcpy(cmd, buf);
     ac = split_buf(s, &av, 1);
 
     /* Do something with the message. */
-    if (call_callback_4(NULL, cb_recvmsg, source, cmd, ac, av) <= 0) {
-	if (!source && stricmp(cmd, "NICK") != 0) {
-	    log("Source missing for `%s' message from server (%s)",cmd,inbuf);
-	} else {
-	    Message *m = find_message(cmd);
-	    if (m) {
-		if (m->func)
-		    m->func(source, ac, av);
-	    } else {
-		log("unknown message from server (%s)", inbuf);
-	    }
-	}
+    if (call_callback_4(cb_recvmsg, source, cmd, ac, av) <= 0) {
+        Message *m = find_message(cmd);
+        if (m) {
+            if (m->func)
+                m->func(source, ac, av);
+        } else {
+            log("unknown message from server (%s)", inbuf);
+        }
     }
 
     /* Finally, clear the first byte of `inbuf' to signal that we're
@@ -153,3 +147,13 @@ void process()
 }
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
