@@ -1,33 +1,35 @@
 /* Routines to maintain a list of online servers.
- * by Andrew Kempe (TheShadow)
+ * Based on code by Andrew Kempe (TheShadow)
  *     E-mail: <theshadow@shadowfire.org>
  *
- * IRC Services is copyright (c) 1996-2009 Andrew Church.
+ * IRC Services is copyright (c) 1996-2008 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
 #include "services.h"
 #include "modules.h"
-#include "hash.h"
 
 /*************************************************************************/
 
-void add_server(Server *server);  /* to avoid "no prototype" warning */
-void del_server(Server *server);  /* same */
+#define add_server  static add_server
+#define del_server  static del_server
+#include "hash.h"
 DEFINE_HASH(server, Server, name)
+#undef add_server
+#undef del_server
 
-static Server *root_server;	/* Entry for root server (Services) */
-static int16 servercnt = 0;	/* Number of online servers */
+static Server *root_server;     /* Entry for root server (Services) */
+static int16 servercnt = 0;     /* Number of online servers */
 
 /* Callback IDs: */
 static int cb_create = -1;
 static int cb_delete = -1;
 
 /*************************************************************************/
-/**************************** Internal Functions *************************/
+/**************************** Internal functions *************************/
 /*************************************************************************/
 
 /* Allocate a new Server structure, fill in basic values, link it to the
@@ -73,13 +75,13 @@ static void squit_server(Server *server, const char *reason)
     if (protocol_features & PF_NOQUIT) {
 #define next snext
 #define prev sprev
-	LIST_FOREACH_SAFE (user, server->userlist, nextuser)
-	    quit_user(user, reason, 0);
+        LIST_FOREACH_SAFE (user, server->userlist, nextuser)
+            quit_user(user, reason, 0);
 #undef next
 #undef prev
     }
     if (!server->fake)
-	call_callback_2(NULL, cb_delete, server, reason);
+        call_callback_2(cb_delete, server, reason);
     delete_server(server);
 }
 
@@ -94,24 +96,22 @@ static void recursive_squit(Server *parent, const char *reason)
     Server *server, *nextserver;
 
     server = parent->child;
-    if (debug >= 2)
-	log("debug: recursive_squit, parent: %s", parent->name);
+    log_debug(2, "recursive_squit, parent: %s", parent->name);
     while (server) {
-	nextserver = server->sibling;
-	if (debug >= 2)
-	    log("debug: recursive_squit, child: %s", server->name);
-	squit_server(server, reason);
-	server = nextserver;
+        nextserver = server->sibling;
+        log_debug(2, "recursive_squit, child: %s", server->name);
+        squit_server(server, reason);
+        server = nextserver;
     }
 }
 
 /*************************************************************************/
-/**************************** External Functions *************************/
+/**************************** External functions *************************/
 /*************************************************************************/
 
 /* Handle a server SERVER command.
- * 	source = server's hub; !*source indicates this is our hub.
- * 	av[0]  = server's name
+ *      source = server's hub; an empty string indicates that this is our hub.
+ *      av[0]  = server's name
  * If ac < 0, the server in av[0] is assumed to be a "dummy" server that
  * should not be passed to the callback (e.g. for JUPE).
  *
@@ -129,36 +129,37 @@ void do_server(const char *source, int ac, char **av)
     server->child = NULL;
     server->sibling = NULL;
 
-    if (*source) {
-	server->hub = get_server(source);
-	if (!server->hub) {
-	    /* PARANOIA: This should NEVER EVER happen, but we check anyway.
-	     *
-	     * I've heard that on older ircds it is possible for "source"
-	     * not to be the new server's hub. This will cause problems.
-	     * -TheShadow
-	     */
-	    wallops(ServerName,
-		    "WARNING: Could not find server \2%s\2 which is supposed "
-		    "to be the hub for \2%s\2", source, av[0]);
-	    log("server: could not find hub %s for %s", source, av[0]);
-	}
+    if (source && *source) {
+        server->hub = get_server(source);
+        if (!server->hub) {
+            /* PARANOIA: This should NEVER EVER happen, but we check anyway.
+             *
+             * I've heard that on older ircds it is possible for "source"
+             * not to be the new server's hub. This will cause problems.
+             * -TheShadow
+             */
+            wallops(ServerName,
+                    "WARNING: Could not find server \2%s\2 which is supposed "
+                    "to be the hub for \2%s\2", source, av[0]);
+            log("server: could not find hub %s for %s", source, av[0]);
+            return;
+        }
     } else {
-	server->hub = root_server;
+        server->hub = root_server;
     }
     if (!server->hub->child) {
-	server->hub->child = server;
+        server->hub->child = server;
     } else {
-	tmpserver = server->hub->child;
-	while (tmpserver->sibling)
-	    tmpserver = tmpserver->sibling;
-	tmpserver->sibling = server;
+        tmpserver = server->hub->child;
+        while (tmpserver->sibling)
+            tmpserver = tmpserver->sibling;
+        tmpserver->sibling = server;
     }
 
     if (ac > 0)
-	call_callback_1(NULL, cb_create, server);
+        call_callback_1(cb_create, server);
     else
-	server->fake = 1;
+        server->fake = 1;
 
     return;
 }
@@ -166,8 +167,8 @@ void do_server(const char *source, int ac, char **av)
 /*************************************************************************/
 
 /* Handle a server SQUIT command.
- * 	av[0] = server's name
- * 	av[1] = quit message
+ *      av[0] = server's name
+ *      av[1] = quit message
  */
 
 void do_squit(const char *source, int ac, char **av)
@@ -177,28 +178,28 @@ void do_squit(const char *source, int ac, char **av)
     server = get_server(av[0]);
 
     if (server) {
-	if (server->hub) {
-	    if (server->hub->child == server) {
-		server->hub->child = server->sibling;
-	    } else {
-		Server *tmpserver;
-		for (tmpserver = server->hub->child; tmpserver->sibling;
-				tmpserver = tmpserver->sibling) {
-		    if (tmpserver->sibling == server) {
-			tmpserver->sibling = server->sibling;
-			break;
-		    }
-		}
-	    }
-	}
-	squit_server(server, av[1]);
+        if (server->hub) {
+            if (server->hub->child == server) {
+                server->hub->child = server->sibling;
+            } else {
+                Server *tmpserver;
+                for (tmpserver = server->hub->child; tmpserver->sibling;
+                                tmpserver = tmpserver->sibling) {
+                    if (tmpserver->sibling == server) {
+                        tmpserver->sibling = server->sibling;
+                        break;
+                    }
+                }
+            }
+        }
+        squit_server(server, av[1]);
 
     } else {
-	wallops(ServerName,
-		"WARNING: Tried to quit non-existent server: \2%s", av[0]);
-	log("server: Tried to quit non-existent server: %s", av[0]);
-	log("server: Input buffer: %s", inbuf);
-	return;
+        wallops(ServerName,
+                "WARNING: Tried to quit non-existent server: \2%s", av[0]);
+        log("server: Tried to quit non-existent server: %s", av[0]);
+        log("server: Input buffer: %s", inbuf);
+        return;
     }
 }
 
@@ -209,11 +210,11 @@ int server_init(int ac, char **av)
 {
     Server *server;
 
-    cb_create = register_callback(NULL, "server create");
-    cb_delete = register_callback(NULL, "server delete");
+    cb_create = register_callback("server create");
+    cb_delete = register_callback("server delete");
     if (cb_create < 0 || cb_delete < 0) {
-	log("server_init: register_callback() failed\n");
-	return 0;
+        log("server_init: register_callback() failed\n");
+        return 0;
     }
     server = new_server("");
     server->fake = 1;
@@ -235,8 +236,8 @@ void server_cleanup(void)
     protocol_features |= PF_NOQUIT;
     squit_server(root_server, "server_cleanup");
     protocol_features = pf;
-    unregister_callback(NULL, cb_delete);
-    unregister_callback(NULL, cb_create);
+    unregister_callback(cb_delete);
+    unregister_callback(cb_create);
 }
 
 /*************************************************************************/
@@ -250,10 +251,20 @@ void get_server_stats(long *nservers, long *memuse)
 
     mem = sizeof(Server) * servercnt;
     for (server = first_server(); server; server = next_server())
-	mem += strlen(server->name)+1;
+        mem += strlen(server->name)+1;
 
     *nservers = servercnt;
     *memuse = mem;
 }
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
